@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,7 @@
 #define ICONCONTAINER_H
 
 #include <QPushButton>
+#include <QProxyStyle>
 
 namespace Peony {
 
@@ -32,11 +33,23 @@ class IconContainer : public QPushButton
     Q_OBJECT
 public:
     explicit IconContainer(QWidget *parent = nullptr);
+    ~IconContainer();
 
 protected:
     void mouseMoveEvent(QMouseEvent *e) {}
     void mousePressEvent(QMouseEvent *e) {}
     void paintEvent(QPaintEvent *e);
+
+private:
+    QStyle *m_style;
+};
+
+class IconContainerStyle : public QProxyStyle
+{
+    friend class IconContainer;
+    explicit IconContainerStyle();
+
+    void drawControl(ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget = nullptr) const override;
 };
 
 #endif // ICONCONTAINER_H
