@@ -24,12 +24,15 @@
 #include "file-info.h"
 #include "file-info-manager.h"
 
+#include "file-info-job.h"
+
 #include "mount-operation.h"
 
 #include "gerror-wrapper.h"
 
 #include "file-utils.h"
 #include "peony-search-vfs-file.h"
+#include "audio-play-manager.h"
 
 #include <QList>
 #include <QMessageBox>
@@ -63,9 +66,11 @@ FileEnumerator::FileEnumerator(QObject *parent) : QObject(parent)
         }
     });
 
-    connect(this, &FileEnumerator::enumerateFinished, this, [=](){
-        *m_children_uris<<*m_cache_uris;
-        childrenUpdated(*m_cache_uris);
+    connect(this, &FileEnumerator::enumerateFinished, this, [=](bool successed){
+        if (successed) {
+            *m_children_uris<<*m_cache_uris;
+            childrenUpdated(*m_cache_uris, true);
+        }
         m_cache_uris->clear();
         m_idle->stop();
     });
@@ -93,6 +98,7 @@ FileEnumerator::FileEnumerator(QObject *parent) : QObject(parent)
  */
 FileEnumerator::~FileEnumerator()
 {
+    g_cancellable_cancel(m_cancellable);
     disconnect();
     //qDebug()<<"~FileEnumerator";
     g_object_unref(m_root_file);
@@ -153,30 +159,29 @@ void FileEnumerator::setEnumerateDirectory(GFile *file)
     }
 }
 
+bool FileEnumerator::setEnumerateWithInfoJob(bool query)
+{
+    m_with_info_job = query;
+}
+
 QString FileEnumerator::getEnumerateUri()
 {
     return m_uri;
 }
 
-const QList<std::shared_ptr<FileInfo>> FileEnumerator::getChildren(bool addToHash)
+const QList<std::shared_ptr<FileInfo>> FileEnumerator::getChildren()
 {
-    m_children_uris->removeDuplicates();
+    //m_children_uris->removeDuplicates();
 
     //qDebug()<<"FileEnumerator::getChildren():";
     QList<std::shared_ptr<FileInfo>> children;
     for (auto uri : *m_children_uris) {
-        auto file_info = FileInfo::fromUri(uri, addToHash);
+        auto file_info = FileInfo::fromUri(uri);
         children<<file_info;
     }
     return children;
 }
 
-const QStringList FileEnumerator::getChildrenUris()
-{
-    m_children_uris->removeDuplicates();
-    return *m_children_uris;
-}
-
 void FileEnumerator::cancel()
 {
     g_cancellable_cancel(m_cancellable);
@@ -190,32 +195,18 @@ void FileEnumerator::cancel()
 
 void FileEnumerator::prepare()
 {
-    GError *err = nullptr;
-    GFileEnumerator *enumerator = g_file_enumerate_children(m_root_file,
-                                  G_FILE_ATTRIBUTE_STANDARD_NAME,
-                                  G_FILE_QUERY_INFO_NONE,
-                                  m_cancellable,
-                                  &err);
-
-    if (err) {
-        //do not send prepared(err) here, wait handle err finished.
-        handleError(err);
-        g_error_free(err);
-    } else {
-        //even though there is no err, we still need to wait a little while
-        //for confirming other object will recieve this signal, you can aslo
-        //connect prepared signal before prepared() method to confirm that.
-        //Q_EMIT prepared(nullptr);
-        g_object_unref(enumerator);
-
-        QTimer::singleShot(100, this, [=]() {
-            Q_EMIT prepared(nullptr);
-        });
-    }
+    g_file_enumerate_children_async(m_root_file,
+                                    G_FILE_ATTRIBUTE_STANDARD_NAME,
+                                    G_FILE_QUERY_INFO_NONE,
+                                    G_PRIORITY_DEFAULT,
+                                    m_cancellable,
+                                    GAsyncReadyCallback(prepare_enumerate_callback),
+                                    this);
 }
 
 GFile *FileEnumerator::enumerateTargetFile()
 {
+    //FIXME: replace BLOCKING api in ui thread.
     GFileInfo *info = g_file_query_info(m_root_file,
                                         G_FILE_ATTRIBUTE_STANDARD_TARGET_URI,
                                         G_FILE_QUERY_INFO_NONE,
@@ -237,6 +228,33 @@ GFile *FileEnumerator::enumerateTargetFile()
     return target;
 }
 
+GAsyncReadyCallback FileEnumerator::prepare_enumerate_callback(GFile *file, GAsyncResult *res, FileEnumerator *p_this)
+{
+    GError *err = nullptr;
+    GFileEnumerator *enumerator = g_file_enumerate_children_finish(file, res, &err);
+
+    if (err && err->code == G_IO_ERROR_CANCELLED) {
+        g_error_free(err);
+        return nullptr;
+    }
+
+    if (err) {
+        //do not send prepared(err) here, wait handle err finished.
+        p_this->handleError(err);
+        g_error_free(err);
+    } else {
+        //even though there is no err, we still need to wait a little while
+        //for confirming other object will recieve this signal, you can aslo
+        //connect prepared signal before prepared() method to confirm that.
+        //Q_EMIT prepared(nullptr);
+        g_object_unref(enumerator);
+
+        Q_EMIT p_this->prepared(nullptr);
+    }
+
+    return nullptr;
+}
+
 void FileEnumerator::enumerateSync()
 {
     m_idle->start(1000);
@@ -275,6 +293,7 @@ void FileEnumerator::handleError(GError *err)
     switch (err->code) {
     case G_IO_ERROR_NOT_DIRECTORY: {
         auto uri = g_file_get_uri(m_root_file);
+        //FIXME: replace BLOCKING api in ui thread.
         auto targetUri = FileUtils::getTargetUri(uri);
         if (uri) {
             g_free(uri);
@@ -285,6 +304,7 @@ void FileEnumerator::handleError(GError *err)
         }
 
         bool isMountable = false;
+        //FIXME: replace BLOCKING api in ui thread.
         GFileInfo *file_mount_info = g_file_query_info(m_root_file, G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT,
                                      G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, nullptr, nullptr);
 
@@ -321,11 +341,10 @@ void FileEnumerator::handleError(GError *err)
                                       this);
         break;
     case G_IO_ERROR_NOT_SUPPORTED:
+        Peony::AudioPlayManager::getInstance()->playWarningAudio();
         QMessageBox::critical(nullptr, tr("Error"), err->message);
         break;
     case G_IO_ERROR_PERMISSION_DENIED:
-        //FIXME: do i need add an auth function for this kind of errors?
-        QMessageBox::critical(nullptr, tr("Error"), err->message);
         //emit error message to upper levels to process
         Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_new(G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED, "permission denied")));
         break;
@@ -333,7 +352,7 @@ void FileEnumerator::handleError(GError *err)
         Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_new(G_IO_ERROR, G_IO_ERROR_NOT_FOUND, "file not found")));
         break;
     default:
-        Q_EMIT prepared(GErrorWrapper::wrapFrom(err), nullptr, true);
+        Q_EMIT prepared(GErrorWrapper::wrapFrom(g_error_copy(err)), nullptr, true);
         break;
     }
 }
@@ -345,7 +364,7 @@ void FileEnumerator::enumerateAsync()
     //auto uri = g_file_get_uri(m_root_file);
     //auto path = g_file_get_path(m_root_file);
     g_file_enumerate_children_async(m_root_file,
-                                    G_FILE_ATTRIBUTE_STANDARD_NAME,
+                                    m_with_info_job? "*::*": G_FILE_ATTRIBUTE_STANDARD_NAME,
                                     G_FILE_QUERY_INFO_NONE,
                                     G_PRIORITY_DEFAULT,
                                     m_cancellable,
@@ -371,7 +390,7 @@ void FileEnumerator::enumerateChildren(GFileEnumerator *enumerator)
 
         QUrl url = QUrl(QString(uri));
         //qDebug()<<uri;
-        if (path && !url.isLocalFile()) {
+        if (path && !url.isLocalFile() && false) {
             QString localUri = QString("file://%1").arg(path);
             *m_children_uris<<localUri;
             g_free(path);
@@ -396,17 +415,28 @@ GAsyncReadyCallback FileEnumerator::mount_mountable_callback(GFile *file,
     GError *err = nullptr;
     GFile *target = g_file_mount_mountable_finish(file, res, &err);
     if (err && err->code != 0) {
+        auto message = err->message;
+        if (err->code == G_IO_ERROR_CANCELLED) {
+            g_error_free(err);
+            return nullptr;
+        }
         qDebug()<<err->code<<err->message;
+        if (!qobject_cast<QObject *>(p_this)) {
+            g_error_free(err);
+            return nullptr;
+        }
         auto err_data = GErrorWrapper::wrapFrom(err);
         Q_EMIT p_this->prepared(err_data);
     } else {
         Q_EMIT p_this->prepared(nullptr);
+        if (err) {
+            g_error_free(err);
+        }
     }
     if (target) {
         g_object_unref(target);
     }
 
-
     return nullptr;
 }
 
@@ -418,6 +448,10 @@ GAsyncReadyCallback FileEnumerator::mount_enclosing_volume_callback(GFile *file,
     GError *err = nullptr;
     if (g_file_mount_enclosing_volume_finish (file, res, &err)) {
         if (err) {
+            if (err->code == G_IO_ERROR_CANCELLED) {
+                g_error_free (err);
+                return nullptr;
+            }
             qDebug()<<"mount successed, err:"<<err->code<<err->message;
             Q_EMIT p_this->prepared(GErrorWrapper::wrapFrom(err), nullptr, true);
         } else {
@@ -425,10 +459,14 @@ GAsyncReadyCallback FileEnumerator::mount_enclosing_volume_callback(GFile *file,
         }
     } else {
         if (err) {
+            if (err->code == G_IO_ERROR_CANCELLED) {
+                return nullptr;
+            }
             if (err->code == G_IO_ERROR_ALREADY_MOUNTED) {
                 Q_EMIT p_this->prepared(GErrorWrapper::wrapFrom(err));
                 return nullptr;
             }
+
             qDebug()<<"mount failed, err:"<<err->code<<err->message;
             //show the connect dialog
             if (!p_this->m_root_file) {
@@ -449,6 +487,7 @@ GAsyncReadyCallback FileEnumerator::mount_enclosing_volume_callback(GFile *file,
                     qDebug()<<"finished err:"<<finished_err->code()<<finished_err->message();
                     if (finished_err->code() == G_IO_ERROR_PERMISSION_DENIED) {
                         p_this->enumerateFinished(false);
+                        Peony::AudioPlayManager::getInstance()->playWarningAudio();
                         QMessageBox::critical(nullptr, tr("Error"), finished_err->message());
                         return;
                     }
@@ -470,6 +509,10 @@ GAsyncReadyCallback FileEnumerator::find_children_async_ready_callback(GFile *fi
     GError *err = nullptr;
     GFileEnumerator *enumerator = g_file_enumerate_children_finish(file, res, &err);
     if (err) {
+        if (err->code == G_IO_ERROR_CANCELLED) {
+            g_error_free(err);
+            return nullptr;
+        }
         qDebug()<<"find children async err:"<<err->code<<err->message;
         //NOTE: if the enumerator file has target uri, but target uri is not mounted,
         //it should be handled.
@@ -509,6 +552,13 @@ GAsyncReadyCallback FileEnumerator::enumerator_next_files_async_ready_callback(G
                    res,
                    &err);
 
+    if (err) {
+        if (err->code == G_IO_ERROR_CANCELLED) {
+            g_error_free(err);
+            return nullptr;
+        }
+    }
+
     auto errPtr = GErrorWrapper::wrapFrom(err);
     if (!files && !err) {
         //if a directory children count is same with BATCH_SIZE,
@@ -539,7 +589,7 @@ GAsyncReadyCallback FileEnumerator::enumerator_next_files_async_ready_callback(G
 
         QUrl url = QUrl(QString(uri));
 
-        if (path && !url.isLocalFile()) {
+        if (path && !url.isLocalFile() && false) {
             QString localUri = QString("file://%1").arg(path);
             uriList<<localUri;
             *(p_this->m_cache_uris)<<localUri;
@@ -549,6 +599,13 @@ GAsyncReadyCallback FileEnumerator::enumerator_next_files_async_ready_callback(G
             *(p_this->m_cache_uris)<<uri;
         }
 
+        if (p_this->m_with_info_job) {
+            auto fileInfo = FileInfo::fromUri(uri);
+            FileInfoJob infoJob(fileInfo);
+            infoJob.refreshInfoContents(info);
+            p_this->m_cached_infos<<fileInfo;
+        }
+
         g_free(uri);
         files_count++;
         l = l->next;
