@@ -41,50 +41,31 @@ using namespace Peony;
 FileInfoJob::FileInfoJob(std::shared_ptr<FileInfo> info, QObject *parent) : QObject(parent)
 {
     m_info = info;
-    connect(m_info.get(), &FileInfo::updated, this, &FileInfoJob::infoUpdated);
+    //connect(m_info.get(), &FileInfo::updated, this, &FileInfoJob::infoUpdated);
+
+    m_cancellable = g_cancellable_new();
 }
 
 FileInfoJob::FileInfoJob(const QString &uri, QObject *parent) : QObject (parent)
 {
     auto info = FileInfo::fromUri(uri);
     m_info = info;
-    connect(m_info.get(), &FileInfo::updated, this, &FileInfoJob::infoUpdated);
+    //connect(m_info.get(), &FileInfo::updated, this, &FileInfoJob::infoUpdated);
+
+    m_cancellable = g_cancellable_new();
 }
 
-/*!
- * \brief FileInfoJob::~FileInfoJob
- * <br>
- * For FileInfo having a handle shared by all classes instance,
- * the shared data first is created in a global hash hold by
- * Peony::FileInfoManager instance. This makes shared_ptr
- * ref count always more than 1.
- * </br>
- * <br>
- * At this class we aslo hold a shared data from global hash
- * (though we aslo change its content here).
- * When info job instance in destructor, it means shared data
- * use count will reduce 1 soon. If current use count is 2,
- * that means there won't be another holder expect global hash.
- * So we can remove the last shared_ptr in the hash, then FileInfo
- * instance will be removed automaticly.
- * </br>
- * \see FileInfo::~FileInfo(), FileEnumerator::~FileEnumerator().
- */
 FileInfoJob::~FileInfoJob()
 {
-    //qDebug()<<"~Job"<<m_info.use_count();
-    if (m_info.use_count() <= 2) {
-        Peony::FileInfoManager *mgr = Peony::FileInfoManager::getInstance();
-        mgr->remove(m_info);
-    }
+    g_object_unref(m_cancellable);
 }
 
 void FileInfoJob::cancel()
 {
     //NOTE: do not use same cancellble for cancelling, otherwise all job might be cancelled.
-    g_cancellable_cancel(m_info->m_cancellable);
-    g_object_unref(m_info->m_cancellable);
-    m_info->m_cancellable = g_cancellable_new();
+    g_cancellable_cancel(m_cancellable);
+    g_object_unref(m_cancellable);
+    m_cancellable = g_cancellable_new();
 }
 
 bool FileInfoJob::querySync()
@@ -117,6 +98,9 @@ bool FileInfoJob::querySync()
     g_object_unref(_info);
     if (m_auto_delete)
         deleteLater();
+
+    infoUpdated();
+
     return true;
 }
 
@@ -134,6 +118,7 @@ GAsyncReadyCallback FileInfoJob::query_info_async_callback(GFile *file, GAsyncRe
         thisJob->refreshInfoContents(_info);
         g_object_unref(_info);
         Q_EMIT thisJob->queryAsyncFinished(true);
+        Q_EMIT thisJob->infoUpdated();
     }
     else {
         qDebug()<<err->code<<err->message;
@@ -159,7 +144,7 @@ void FileInfoJob::queryAsync()
                             "standard::*," "time::*," "access::*," "mountable::*," "metadata::*," G_FILE_ATTRIBUTE_ID_FILE,
                             G_FILE_QUERY_INFO_NONE,
                             G_PRIORITY_DEFAULT,
-                            info->m_cancellable,
+                            m_cancellable,
                             GAsyncReadyCallback(query_info_async_callback),
                             this);
 
@@ -169,8 +154,8 @@ void FileInfoJob::queryAsync()
 
 void FileInfoJob::refreshInfoContents(GFileInfo *new_info)
 {
-    if (!m_info->m_mutex.tryLock(300))
-        return;
+//    if (!m_info->m_mutex.tryLock(300))
+//        return;
 
     FileInfo *info = nullptr;
     if (auto data = m_info) {
@@ -212,6 +197,8 @@ void FileInfoJob::refreshInfoContents(GFileInfo *new_info)
     info->m_can_stop = g_file_info_get_attribute_boolean(new_info, G_FILE_ATTRIBUTE_MOUNTABLE_CAN_STOP);
 
     info->m_is_virtual = g_file_info_get_attribute_boolean(new_info, G_FILE_ATTRIBUTE_STANDARD_IS_VIRTUAL);
+    if(g_file_info_has_attribute(new_info,G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE_FILE))
+        info->m_unix_device_file = g_file_info_get_attribute_string(new_info,G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE_FILE);
 
     info->m_display_name = QString (g_file_info_get_display_name(new_info));
     GIcon *g_icon = g_file_info_get_icon (new_info);
@@ -282,6 +269,7 @@ void FileInfoJob::refreshInfoContents(GFileInfo *new_info)
     m_info->m_colors = FileLabelModel::getGlobalModel()->getFileColors(m_info->uri());
 
     if (info->isDesktopFile()) {
+        info->m_desktop_name = info->displayName();
         QUrl url = info->uri();
         GDesktopAppInfo *desktop_info = g_desktop_app_info_new_from_filename(url.path().toUtf8());
         if (!desktop_info) {
@@ -319,8 +307,11 @@ void FileInfoJob::refreshInfoContents(GFileInfo *new_info)
         g_object_unref(desktop_info);
     }
 
+    info->m_target_uri = g_file_info_get_attribute_string(new_info, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI);
+    info->m_symlink_target = g_file_info_get_symlink_target(new_info);
+
     Q_EMIT info->updated();
-    m_info->m_mutex.unlock();
+//    m_info->m_mutex.unlock();
 }
 
 QString FileInfoJob::getAppName(QString desktopfp)
