@@ -33,6 +33,7 @@
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QDebug>
 
 using namespace Peony;
 
@@ -61,7 +62,11 @@ FileLauchDialog::FileLauchDialog(const QString &uri, QWidget *parent) : QDialog(
     m_uri = uri;
     auto actions = FileLaunchManager::getAllActions(uri);
     for (auto action : actions) {
+        //fix show no icon app in list issue, bug#18171
+        if (action->icon().isNull())
+            continue;
         action->setParent(this);
+        //qDebug() << "lauch actions:" <<action->icon() <<action->iconText() <<action->text();
         auto item = new QListWidgetItem(!action->icon().isNull()? action->icon(): QIcon::fromTheme("application-x-desktop"),
                                         action->text(),
                                         m_view);
