@@ -65,6 +65,8 @@ public Q_SLOTS:
     void lauchFileAsync(bool forceWithArg = false, bool skipDialog = true);
     void lauchFilesAsync(const QStringList files, bool forceWithArg = false, bool skipDialog = true);
 
+    bool isExcuteableFile(QString fileType);
+
 private:
     QString m_uri;
     bool m_is_desktop_file;
@@ -74,6 +76,10 @@ private:
     QString m_info_name;
     QString m_info_display_name;
 
+    QStringList m_executable_type = {"application/x-shellscript", "application/x-executable", "application/x-perl",
+                                    "application/x-sharedlib", "text/x-python3", "application/javascript",
+                                    "application/x-ruby"};
+
     /*!
      * \brief m_force_with_arg
      * \value true for forcing to execute action asynchonously.
