@@ -121,7 +121,9 @@ const QList<FileLaunchAction*> FileLaunchManager::getAllActionsForType(const QSt
     QList<FileLaunchAction *> actions;
     while (l) {
         auto app_info = static_cast<GAppInfo*>(l->data);
-        actions<<new FileLaunchAction(uri, app_info, true);
+        //only show available applications
+        if (g_app_info_should_show(app_info))
+           actions<<new FileLaunchAction(uri, app_info, true);
         g_object_unref(app_info);
         l = l->next;
     }
@@ -135,7 +137,9 @@ const QList<FileLaunchAction*> FileLaunchManager::getAllActions(const QString &u
     QList<FileLaunchAction *> actions;
     while (l) {
         auto app_info = static_cast<GAppInfo*>(l->data);
-        actions<<new FileLaunchAction(uri, app_info, true);
+        //only show available applications
+        if (g_app_info_should_show(app_info))
+           actions<<new FileLaunchAction(uri, app_info, true);
         g_object_unref(app_info);
         l = l->next;
     }
@@ -157,6 +161,7 @@ void FileLaunchManager::openSync(const QString &uri, bool forceWithArg, bool ski
 void FileLaunchManager::openAsync(const QString &uri, bool forceWithArg, bool skipDialog)
 {
     QString tmp = uri;
+    //FIXME: replace BLOCKING api in ui thread.
     auto targetUri = FileUtils::getTargetUri(uri);
     if (!targetUri.isNull()) {
         tmp = targetUri;
@@ -170,6 +175,7 @@ void FileLaunchManager::openAsync(const QString &uri, bool forceWithArg, bool sk
 void FileLaunchManager::openAsync(const QStringList &files, bool forceWithArg, bool skipDialog)
 {
     QString tmp = files.at(0);
+    //FIXME: replace BLOCKING api in ui thread.
     auto targetUri = FileUtils::getTargetUri(tmp);
     if (!targetUri.isNull()) {
         tmp = targetUri;
