@@ -36,24 +36,23 @@ using namespace Peony;
 #define TEMPLATE_DIR "file://" + QString(g_get_user_special_dir(G_USER_DIRECTORY_TEMPLATES)) + "/"
 
 void CreateTemplateOperation::handleDuplicate(const QString &uri) {
-    setHasError(true);
     QString name = uri.split("/").last();
-    QRegExp regExp("\\(\\d+\\)");
+    QRegExp regExpNum("^\\(\\d+\\)");
+    QRegExp regExp("\\(\\d+\\)(\\.[0-9a-zA-Z]+|)$");
     if (name.contains(regExp)) {
-        int pos = 0;
         int num = 0;
-        QString tmp;
-        while ((pos = regExp.indexIn(name, pos)) != -1) {
-            tmp = regExp.cap(0).toUtf8();
-            pos += regExp.matchedLength();
-            qDebug()<<"pos"<<pos;
-        }
-        tmp.remove(0,1);
-        tmp.chop(1);
-        num = tmp.toInt();
+        QString numStr = "";
 
-        num++;
-        name = name.replace(regExp, QString("(%1)").arg(num));
+        QString ext = regExp.cap(0);
+        if (ext.contains(regExpNum)) {
+            numStr = regExpNum.cap(0);
+        }
+
+        numStr.remove(0, 1);
+        numStr.chop(1);
+        num = numStr.toInt();
+        ++num;
+        name = name.replace(regExp, ext.replace(regExpNum, QString("(%1)").arg(num)));
         m_target_uri = m_dest_dir_uri + "/" + name;
     } else {
         if (name.contains(".")) {
@@ -126,8 +125,10 @@ retry_create_empty_file:
                 except.dlgType = ED_WARNING;
                 except.destDirUri = m_dest_dir_uri;
                 except.isCritical = true;
+                except.op = FileOpCreateTemp;
                 except.title = tr("Create file");
                 except.errorCode = err->code;
+                except.errorStr = err->message;
                 except.errorType = ET_GIO;
                 Q_EMIT errored(except);
             }
@@ -153,8 +154,10 @@ retry_create_empty_folder:
                 except.dlgType = ED_WARNING;
                 except.destDirUri = m_dest_dir_uri;
                 except.isCritical = true;
-                except.title = tr("Create file");
+                except.op = FileOpCreateTemp;
+                except.title = tr("Create file error");
                 except.errorCode = err->code;
+                except.errorStr = err->message;
                 except.errorType = ET_GIO;
                 Q_EMIT errored(except);
             }
@@ -173,6 +176,7 @@ retry_create_template:
                     nullptr,
                     &err);
         if (err) {
+            setHasError(true);
             if (err->code == G_IO_ERROR_EXISTS) {
                 g_error_free(err);
                 handleDuplicate(m_target_uri);
@@ -183,11 +187,15 @@ retry_create_template:
                 except.dlgType = ED_WARNING;
                 except.destDirUri = m_dest_dir_uri;
                 except.isCritical = true;
-                except.title = tr("Create file");
+                except.op = FileOpCreateTemp;
+                except.title = tr("Create file error");
                 except.errorCode = err->code;
+                except.errorStr = err->message;
                 except.errorType = ET_GIO;
                 Q_EMIT errored(except);
             }
+        } else {
+            setHasError(false);
         }
         // change file's modify time and access time after copy templete file;
         time_t now_time = time(NULL);
@@ -239,6 +247,11 @@ retry_create_template:
         }
     }
 
+    // as target()
+    m_info.get()->m_dest_dir_uri = m_target_uri;
+    m_info.get()->m_dest_uris.clear();
+    m_info.get()->m_dest_uris<<m_target_uri;
+
     Q_EMIT operationFinished();
     notifyFileWatcherOperationFinished();
 }
