@@ -39,22 +39,22 @@ using namespace Peony;
 
 static void handleDuplicate(FileNode *node) {
     QString name = node->destBaseName();
-    QRegExp regExp("\\(\\d+\\)");
+    QRegExp regExpNum("^\\(\\d+\\)");
+    QRegExp regExp("\\(\\d+\\)(\\.[0-9a-zA-Z]+|)$");
     if (name.contains(regExp)) {
-        int pos = 0;
         int num = 0;
-        QString tmp;
-        while ((pos = regExp.indexIn(name, pos)) != -1) {
-            tmp = regExp.cap(0).toUtf8();
-            pos += regExp.matchedLength();
-            qDebug()<<"pos"<<pos;
-        }
-        tmp.remove(0,1);
-        tmp.chop(1);
-        num = tmp.toInt();
+        QString numStr = "";
 
-        num++;
-        name = name.replace(regExp, QString("(%1)").arg(num));
+        QString ext = regExp.cap(0);
+        if (ext.contains(regExpNum)) {
+            numStr = regExpNum.cap(0);
+        }
+
+        numStr.remove(0, 1);
+        numStr.chop(1);
+        num = numStr.toInt();
+        ++num;
+        name = name.replace(regExp, ext.replace(regExpNum, QString("(%1)").arg(num)));
         node->setDestFileName(name);
     } else {
         if (name.contains(".")) {
@@ -127,12 +127,22 @@ ExceptionResponse FileCopyOperation::prehandle(GError *err)
 {
     setHasError(true);
 
-    if (G_IO_ERROR_NO_SPACE == err->code) {
-        return Other;
+    switch (err->code) {
+        case G_IO_ERROR_BUSY:
+        case G_IO_ERROR_PENDING:
+        case G_IO_ERROR_NO_SPACE:
+        case G_IO_ERROR_CANCELLED:
+        case G_IO_ERROR_INVALID_DATA:
+        case G_IO_ERROR_NOT_SUPPORTED:
+        case G_IO_ERROR_PERMISSION_DENIED:
+        case G_IO_ERROR_CANT_CREATE_BACKUP:
+        case G_IO_ERROR_TOO_MANY_OPEN_FILES:
+            return Other;
     }
 
-    if (m_is_duplicated_copy)
+    if (G_IO_ERROR_EXISTS == err->code && m_is_duplicated_copy) {
         return BackupAll;
+    }
 
     if (m_prehandle_hash.contains(err->code))
         return m_prehandle_hash.value(err->code);
@@ -147,13 +157,14 @@ void FileCopyOperation::progress_callback(goffset current_num_bytes,
     if (total_num_bytes < current_num_bytes)
         return;
 
+    QUrl url(p_this->m_current_src_uri);
     auto currnet = p_this->m_current_offset + current_num_bytes;
     auto total = p_this->m_total_szie;
+    auto fileIconName = FileUtils::getFileIconName(p_this->m_current_src_uri, false);
+    auto destFileName = FileUtils::isFileDirectory(p_this->m_current_dest_dir_uri) ?
+                p_this->m_current_dest_dir_uri + "/" + url.fileName() : p_this->m_current_dest_dir_uri;
     qDebug()<<currnet*1.0/total;
-    Q_EMIT p_this->FileProgressCallback(p_this->m_current_src_uri,
-                                        p_this->m_current_dest_dir_uri,
-                                        currnet,
-                                        total);
+    Q_EMIT p_this->FileProgressCallback(p_this->m_current_src_uri, destFileName, fileIconName, currnet, total);
 }
 
 void FileCopyOperation::copyRecursively(FileNode *node)
@@ -191,7 +202,8 @@ fallback_retry:
             except.errorType = ET_GIO;
             except.srcUri = m_current_src_uri;
             except.destDirUri = m_current_dest_dir_uri;
-            except.title = tr("File copy");
+            except.op = FileOpCopy;
+            except.title = tr("File copy error");
             except.errorCode = err->code;
             if (handle_type == Other) {
                 if (G_IO_ERROR_EXISTS == err->code) {
@@ -310,7 +322,8 @@ fallback_retry:
             auto errWrapperPtr = GErrorWrapper::wrapFrom(err);
             int handle_type = prehandle(err);
             except.errorType = ET_GIO;
-            except.title = tr("File copy");
+            except.op = FileOpCopy;
+            except.title = tr("File copy error");
             except.srcUri = m_current_src_uri;
             except.errorCode = err->code;
             except.errorStr = err->message;
@@ -521,6 +534,8 @@ void FileCopyOperation::run()
         delete node;
     }
 
+    m_info->m_dest_uris = m_info->m_node_map.values();
+
     nodes.clear();
 
     // judge if the operation should sync.
