@@ -50,6 +50,7 @@ void FileDeleteOperation::deleteRecursively(FileNode *node)
     if (isCancelled())
         return;
 
+    auto fileIconName = FileUtils::getFileIconName(node->uri(), false);
     GFile *file = g_file_new_for_uri(node->uri().toUtf8().constData());
     if (node->isFolder()) {
         for (auto child : *(node->children())) {
@@ -69,7 +70,8 @@ void FileDeleteOperation::deleteRecursively(FileNode *node)
             except.errorType = ET_GIO;
             except.dlgType = ED_WARNING;
             except.srcUri = node->uri();
-            except.title = tr("File delete");
+            except.op = FileOpDelete;
+            except.title = tr("File delete error");
             except.errorStr = err->message;
             except.errorCode = err->code;
             Q_EMIT errored(except);
@@ -94,7 +96,8 @@ void FileDeleteOperation::deleteRecursively(FileNode *node)
             except.errorType = ET_GIO;
             except.dlgType = ED_WARNING;
             except.srcUri = node->uri();
-            except.title = tr("File delete");
+            except.op = FileOpDelete;
+            except.title = tr("File delete error");
             except.errorCode = err->code;
             except.errorStr = err->message;
             Q_EMIT errored(except);
@@ -112,7 +115,8 @@ void FileDeleteOperation::deleteRecursively(FileNode *node)
     qDebug()<<"deleted";
     //operationAfterProgressedOne(node->uri());
     m_current_offset += node->size();
-    FileProgressCallback(node->uri(), node->uri(), m_current_offset, m_total_szie);
+
+    FileProgressCallback(node->uri(), node->uri(), fileIconName, m_current_offset, m_total_szie);
 }
 
 void FileDeleteOperation::run()
