@@ -52,8 +52,6 @@ FileLinkOperation::~FileLinkOperation()
 
 }
 
-#include <syslog.h>
-
 void FileLinkOperation::run()
 {
     operationStarted();
@@ -73,7 +71,8 @@ retry:
         except.isCritical = true;
         except.errorStr = err->message;
         except.errorCode = err->code;
-        except.title = tr("Link file");
+        except.op = FileOpLink;
+        except.title = tr("Link file error");
         except.destDirUri = m_dest_uri;
         auto responseType = Invalid;
         if (G_IO_ERROR_EXISTS == err->code) {
