@@ -34,22 +34,22 @@ using namespace Peony;
 
 static void handleDuplicate(FileNode *node) {
     QString name = node->destBaseName();
-    QRegExp regExp("\\(\\d+\\)");
+    QRegExp regExpNum("^\\(\\d+\\)");
+    QRegExp regExp("\\(\\d+\\)(\\.[0-9a-zA-Z]+|)$");
     if (name.contains(regExp)) {
-        int pos = 0;
         int num = 0;
-        QString tmp;
-        while ((pos = regExp.indexIn(name, pos)) != -1) {
-            tmp = regExp.cap(0).toUtf8();
-            pos += regExp.matchedLength();
-            qDebug()<<"pos"<<pos;
-        }
-        tmp.remove(0,1);
-        tmp.chop(1);
-        num = tmp.toInt();
+        QString numStr = "";
 
-        num++;
-        name = name.replace(regExp, QString("(%1)").arg(num));
+        QString ext = regExp.cap(0);
+        if (ext.contains(regExpNum)) {
+            numStr = regExpNum.cap(0);
+        }
+
+        numStr.remove(0, 1);
+        numStr.chop(1);
+        num = numStr.toInt();
+        ++num;
+        name = name.replace(regExp, ext.replace(regExpNum, QString("(%1)").arg(num)));
         node->setDestFileName(name);
     } else {
         if (name.contains(".")) {
@@ -109,12 +109,14 @@ void FileMoveOperation::progress_callback(goffset current_num_bytes,
     if (total_num_bytes < current_num_bytes)
         return;
 
+    QUrl url(p_this->m_current_src_uri);
     auto currnet = p_this->m_current_offset + current_num_bytes;
     auto total = p_this->m_total_szie;
-    Q_EMIT p_this->FileProgressCallback(p_this->m_current_src_uri,
-                                        p_this->m_current_dest_dir_uri,
-                                        currnet,
-                                        total);
+    auto fileIconName = FileUtils::getFileIconName(p_this->m_current_src_uri, false);
+    auto destFileName = FileUtils::isFileDirectory(p_this->m_current_dest_dir_uri) ?
+                p_this->m_current_dest_dir_uri + "/" + url.fileName() : p_this->m_current_dest_dir_uri;
+
+    Q_EMIT p_this->FileProgressCallback(p_this->m_current_src_uri, destFileName, fileIconName, currnet, total);
     //format: move srcUri to destDirUri: curent_bytes(count) of total_bytes(count).
 }
 
@@ -197,8 +199,10 @@ retry:
             except.srcUri = srcUri;
             except.destDirUri = m_dest_dir_uri;
             except.isCritical = false;
-            except.title = tr("Move file");
+            except.op = FileOpMove;
+            except.title = tr("Move file error");
             except.errorCode = err->code;
+            except.errorStr = err->message;
             except.errorType = ET_GIO;
             if (handle_type == Other) {
                 auto responseTypeWrapper = Invalid;
@@ -320,7 +324,9 @@ retry:
             except.srcUri = srcUri;
             except.errorType = ET_GIO;
             except.errorCode = err->code;
-            except.title = tr("Move file");
+            except.errorStr = err->message;
+            except.op = FileOpMove;
+            except.title = tr("Move file error");
             except.destDirUri = m_dest_dir_uri;
             except.isCritical = true;
             if (handled_err) {
@@ -530,8 +536,7 @@ void FileMoveOperation::copyRecursively(FileNode *node)
     QString relativePath = node->getRelativePath();
     //FIXME: the smart pointers' deconstruction spends too much time.
     GFileWrapperPtr destRoot = wrapGFile(g_file_new_for_uri(m_dest_dir_uri.toUtf8().constData()));
-    GFileWrapperPtr destFile = wrapGFile(g_file_resolve_relative_path(destRoot.get()->get(),
-                                         relativePath.toUtf8().constData()));
+    GFileWrapperPtr destFile = wrapGFile(g_file_resolve_relative_path(destRoot.get()->get(), relativePath.toUtf8().constData()));
 
     char *dest_file_uri = g_file_get_uri(destFile.get()->get());
     node->setDestUri(dest_file_uri);
@@ -546,15 +551,11 @@ void FileMoveOperation::copyRecursively(FileNode *node)
 fallback_retry:
     if (node->isFolder()) {
         GError *err = nullptr;
-
+        auto fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
+        auto destFileName = FileUtils::isFileDirectory(m_current_dest_dir_uri) ? nullptr : m_current_dest_dir_uri;
         //NOTE: mkdir doesn't have a progress callback.
-        Q_EMIT FileProgressCallback(m_current_src_uri,
-                                    m_current_dest_dir_uri,
-                                    node->size(),
-                                    node->size());
-        g_file_make_directory(destFile.get()->get(),
-                              getCancellable().get()->get(),
-                              &err);
+        Q_EMIT FileProgressCallback(m_current_src_uri, destFileName, fileIconName, node->size(), node->size());
+        g_file_make_directory(destFile.get()->get(),getCancellable().get()->get(), &err);
         if (err) {
             FileOperationError except;
             if (err->code == G_IO_ERROR_CANCELLED) {
@@ -563,7 +564,8 @@ fallback_retry:
             auto errWrapperPtr = GErrorWrapper::wrapFrom(err);
             int handle_type = prehandle(err);
             except.errorType = ET_GIO;
-            except.title = tr("Move file");
+            except.op = FileOpMove;
+            except.title = tr("Move file error");
             except.errorCode = err->code;
             except.errorStr = err->message;
             except.srcUri = m_current_src_uri;
@@ -634,14 +636,20 @@ fallback_retry:
                 if (FileUtils::isFileExsit(node->destUri())) {
                     handleDuplicate(node);
                 }
-                break;
+                g_object_unref(destFile.get());
+                destFile = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+                goto fallback_retry;
             }
             case BackupAll: {
                 node->setState(FileNode::Handled);
                 node->setErrorResponse(BackupOne);
-                //make dir has no backup
+                if (FileUtils::isFileExsit(node->destUri())) {
+                    handleDuplicate(node);
+                }
                 m_prehandle_hash.insert(err->code, BackupOne);
-                break;
+                g_object_unref(destFile.get());
+                destFile = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+                goto fallback_retry;
             }
             case Retry: {
                 goto fallback_retry;
@@ -657,12 +665,12 @@ fallback_retry:
         } else {
             node->setState(FileNode::Handled);
         }
+
+        fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
+        destFileName = FileUtils::isFileDirectory(m_current_dest_dir_uri) ? nullptr : m_current_dest_dir_uri;
         //assume that make dir finished anyway
         m_current_offset += node->size();
-        Q_EMIT FileProgressCallback(m_current_src_uri,
-                                    m_current_dest_dir_uri,
-                                    m_current_offset,
-                                    m_total_szie);
+        Q_EMIT FileProgressCallback(m_current_src_uri, destFileName, fileIconName, m_current_offset, m_total_szie);
         Q_EMIT operationProgressedOne(node->uri(), node->destUri(), node->size());
         for (auto child : *(node->children())) {
             copyRecursively(child);
@@ -689,7 +697,8 @@ fallback_retry:
             except.errorType = ET_GIO;
             except.errorCode = err->code;
             except.errorStr = err->message;
-            except.title = tr("Create file");
+            except.op = FileOpMove;
+            except.title = tr("Create file error");
             except.srcUri = m_current_src_uri;
             except.destDirUri = m_current_dest_dir_uri;
             if (handle_type == Other) {
@@ -806,7 +815,9 @@ fallback_retry:
             node->setState(FileNode::Handled);
         }
         m_current_offset += node->size();
-        Q_EMIT FileProgressCallback(node->uri(), node->destUri(), m_current_offset, m_total_szie);
+        auto fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
+        auto destFileName = FileUtils::isFileDirectory(node->destUri()) ? nullptr : node->destUri();
+        Q_EMIT FileProgressCallback(node->uri(), destFileName, fileIconName, m_current_offset, m_total_szie);
         Q_EMIT operationProgressedOne(node->uri(), node->destUri(), node->size());
     }
     destFile.reset();
@@ -928,7 +939,8 @@ start:
         except.dlgType = ED_WARNING;
         except.srcUri = nullptr;
         except.destDirUri = nullptr;
-        except.title = tr("File delete");
+        except.op = FileOpMove;
+        except.title = tr("File delete error");
         except.errorCode = G_IO_ERROR_INVAL;
         except.errorStr = tr("Invalid Operation");
         Q_EMIT errored(except);
