@@ -49,10 +49,17 @@ FileOperationProgressBar *FileOperationProgressBar::getInstance()
 
 void FileOperationProgressBar::removeAllProgressbar()
 {
-    for (auto pg = m_widget_list->constBegin(); pg != m_widget_list->constEnd(); ++pg) {
-        if (nullptr != pg.key()) delete pg.key();
-        if (nullptr != pg.value()) delete pg.value();
+    if (nullptr != m_main_progressbar && nullptr != m_current_main) {
+        m_main_progressbar->disconnect(m_current_main, &ProgressBar::sendValue, 0, 0);
+        m_current_main = nullptr;
     }
+
+    for (auto pg = m_widget_list->constBegin(); pg != m_widget_list->constEnd(); ++pg) {
+        if (pg.value()->m_current_size > 0) continue;
+        if (nullptr != pg.value()) pg.value()->deleteLater();
+        if (nullptr != pg.key()) delete pg.key();
+    }
+
     m_widget_list->clear();
     m_list_widget->clear();
     m_progress_list->clear();
@@ -72,7 +79,7 @@ ProgressBar *FileOperationProgressBar::addFileOperation()
 
     li->setFlags(Qt::NoItemFlags);
 
-    connect(proc, &ProgressBar::finished, this, &FileOperationProgressBar::removeFileOperation);
+    proc->connect(proc, &ProgressBar::finished, this, &FileOperationProgressBar::removeFileOperation);
     ++m_progress_size;
 
     if (nullptr == m_current_main) {
@@ -97,7 +104,6 @@ void FileOperationProgressBar::removeFileOperation(ProgressBar *progress)
     progress->hide();
     QListWidgetItem* li = (*m_progress_list)[progress];
 
-    // delete from map
     m_list_widget->removeItemWidget(li);
     m_progress_list->remove(progress);
     m_widget_list->remove(li);
@@ -115,7 +121,7 @@ void FileOperationProgressBar::removeFileOperation(ProgressBar *progress)
     }
 
     // free progress
-    delete progress;
+    progress->deleteLater();
     delete li;
 
     if (m_progress_size <= 0) {
@@ -152,7 +158,7 @@ FileOperationProgressBar::FileOperationProgressBar(QWidget *parent) : QWidget(pa
 
     showWidgetList(false);
 
-    connect(m_main_progressbar, &MainProgressBar::minimized, [=](){
+    connect(m_main_progressbar, &MainProgressBar::minimized, [=]() {
         this->showMinimized();
     });
     connect(m_main_progressbar, &MainProgressBar::closeWindow, [=](){
@@ -235,7 +241,6 @@ void FileOperationProgressBar::showWidgetList(bool show)
 
 void FileOperationProgressBar::mainProgressChange(QListWidgetItem *item)
 {
-    // disconnect
     if (nullptr != m_main_progressbar && nullptr != m_current_main) {
         m_main_progressbar->disconnect(m_current_main, &ProgressBar::sendValue, 0, 0);
     }
@@ -254,8 +259,8 @@ void FileOperationProgressBar::mainProgressChange(QListWidgetItem *item)
 
 void FileOperationProgressBar::showDelay(int msec)
 {
-    QTimer::singleShot(msec, this, [=](){
-        if (m_list_widget->count() > 0) {
+    QTimer::singleShot(msec, this, [=] () {
+        if (m_list_widget->count() > 0 && !m_error) {
             show();
         }
     });
@@ -278,7 +283,7 @@ void MainProgressBar::initPrarm()
     m_file_name = tr("starting ...");
 }
 
-void MainProgressBar::setFileIcon(QIcon icon)
+void MainProgressBar::setFileIcon(QIcon& icon)
 {
     m_icon = icon;
 }
@@ -457,13 +462,14 @@ void MainProgressBar::cancelld()
     update();
 }
 
-void MainProgressBar::updateValue(QString& name, double value)
+void MainProgressBar::updateValue(QString& name, QIcon& icon, double value)
 {
     if (value >= 0 && value <= 1) {
         m_current_value = value;
     }
 
     m_file_name = name;
+    m_icon = icon;
 
     update();
 }
@@ -544,12 +550,16 @@ ProgressBar::ProgressBar(QWidget *parent) : QWidget(parent)
     connect(this, &ProgressBar::cancelled, this, &ProgressBar::onCancelled);
 }
 
-void ProgressBar::setIcon(QIcon icon)
+void ProgressBar::setIcon(const QString& icon)
 {
-    m_icon = icon;
+    if (nullptr != icon && "" != icon) {
+        m_icon = QIcon::fromTheme(icon);
+    } else {
+        m_icon = QIcon::fromTheme("text");
+    }
 }
 
-QIcon ProgressBar::getIcon()
+QIcon& ProgressBar::getIcon()
 {
     return m_icon;
 }
@@ -650,14 +660,18 @@ void ProgressBar::mouseReleaseEvent(QMouseEvent *event)
                            QMessageBox::Ok | QMessageBox::Cancel);
         msgBox.button(QMessageBox::Ok)->setText(tr("OK"));
         msgBox.button(QMessageBox::Cancel)->setText(tr("Cancel"));
-        if (QMessageBox::Ok == msgBox.exec()) {
+        if (QMessageBox::Ok == msgBox.exec() && ! m_is_stopping) {
             m_is_stopping = true;
             Q_EMIT cancelled();
+            if (m_current_value <= 0) {
+                Q_EMIT finished(this);
+            }
         }
     }
 
     QWidget::mouseReleaseEvent(event);
-    update();
+    if (! m_is_stopping)
+       update();
 }
 
 void ProgressBar::onCancelled()
@@ -672,7 +686,7 @@ void ProgressBar::updateValue(double value)
         m_current_value = value;
     }
 
-    Q_EMIT sendValue(m_dest_uri, m_current_value);
+    Q_EMIT sendValue(m_dest_uri, getIcon(), m_current_value);
     update();
 }
 
@@ -701,7 +715,7 @@ void ProgressBar::onFileOperationProgressedOne(const QString &uri, const QString
     Q_UNUSED(destUri);
 }
 
-void ProgressBar::updateProgress(const QString &srcUri, const QString &destUri, quint64 current, quint64 total)
+void ProgressBar::updateProgress(const QString &srcUri, const QString &destUri, const QString& fIcon, const quint64& current, const quint64& total)
 {
     if (current >= m_total_size) {
         return;
@@ -709,38 +723,14 @@ void ProgressBar::updateProgress(const QString &srcUri, const QString &destUri,
 
     QUrl srcUrl = srcUri;
     m_src_uri = srcUrl.toDisplayString();
-    QUrl destUrl = destUri;
-    m_dest_uri = destUrl.toDisplayString();
+    if (nullptr != destUri) {
+        QUrl destUrl = destUri;
+        m_dest_uri = destUrl.toDisplayString();
+    }
 
-    // maybe you don't need to show every file icon,just default.
-//    QIcon ficon;
-//    GIcon* fileIcon = nullptr;
-//    char* iconName = nullptr;
-//    GFileInfo* fileInfo = nullptr;
-//    GFile* file = g_file_new_for_uri(srcUri.toUtf8().constData());
-//    if (nullptr != file) {
-//        fileInfo = g_file_query_info(file, "*", G_FILE_QUERY_INFO_NONE, nullptr, nullptr);
-//        if (nullptr != fileInfo) {
-//            fileIcon = g_file_info_get_icon(fileInfo);
-//            if (nullptr != fileIcon) {
-//                iconName = g_icon_to_string(fileIcon);
-//                if (nullptr != iconName) {
-//                    ficon = QIcon(QString(iconName).split(" ").last());
-//                    qDebug() << "-------------->" << iconName;
-//                    setIcon(ficon);
-//                }
-//                if (nullptr != iconName) {
-//                    g_free(iconName);
-//                }
-//            }
-//        }
-//        if (nullptr != fileInfo) {
-//            g_object_unref(fileInfo);
-//        }
-//    }
-//    if (nullptr != file) {
-//        g_object_unref(file);
-//    }
+    if (fIcon != getIcon().name()) {
+        setIcon(fIcon);
+    }
 
     double currentPercent = current * 1.0 / total;
     updateValue(currentPercent);
