@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,10 @@
  *
  */
 
+#include <QApplication>
+
 #include "file-operation.h"
+#include "file-operation-manager.h"
 
 using namespace Peony;
 
@@ -45,3 +48,14 @@ void FileOperation::cancel()
     g_cancellable_cancel(m_cancellable_wrapper.get()->get());
     m_is_cancelled = true;
 }
+
+void FileOperation::notifyFileWatcherOperationFinished()
+{
+    if (!qApp->allWidgets().isEmpty()) {
+        // notify operation for file watchers.
+        auto info = this->getOperationInfo();
+        qDebug()<<info->m_src_dir_uri;
+        if (info)
+            FileOperationManager::getInstance()->manuallyNotifyDirectoryChanged(info.get());
+    }
+}
