@@ -32,22 +32,22 @@
 using namespace Peony;
 
 static QString handleDuplicate(QString name) {
-    QRegExp regExp("\\(\\d+\\)");
+    QRegExp regExpNum("^\\(\\d+\\)");
+    QRegExp regExp("\\(\\d+\\)(\\.[\\.0-9a-zA-Z]+|)$");
     if (name.contains(regExp)) {
-        int pos = 0;
         int num = 0;
-        QString tmp;
-        while ((pos = regExp.indexIn(name, pos)) != -1) {
-            tmp = regExp.cap(0).toUtf8();
-            pos += regExp.matchedLength();
-            qDebug()<<"pos"<<pos;
-        }
-        tmp.remove(0,1);
-        tmp.chop(1);
-        num = tmp.toInt();
+        QString numStr = "";
 
-        num++;
-        name = name.replace(regExp, QString("(%1)").arg(num));
+        QString ext = regExp.cap(0);
+        if (ext.contains(regExpNum)) {
+            numStr = regExpNum.cap(0);
+        }
+
+        numStr.remove(0, 1);
+        numStr.chop(1);
+        num = numStr.toInt();
+        ++num;
+        name = name.replace(regExp, ext.replace(regExpNum, QString("(%1)").arg(num)));
         return name;
     } else {
         if (name.contains(".")) {
@@ -192,9 +192,11 @@ fallback_retry:
             except.srcUri = m_uri;
             except.destDirUri = FileUtils::getFileUri(newFile);
             except.isCritical = true;
-            except.title = tr("Rename file");
+            except.op = FileOpRename;
+            except.title = tr("Rename file error");
             except.errorType = ET_GIO;
             except.errorCode = err->code;
+            except.errorStr = err->message;
             if (G_IO_ERROR_EXISTS == err->code) {
                 except.dlgType = ED_CONFLICT;
                 auto responseType = except.respCode;
@@ -229,7 +231,8 @@ retry:
         except.destDirUri = FileUtils::getFileUri(newFile);
         except.isCritical = true;
         except.errorType = ET_GIO;
-        except.title = tr("Rename file");
+        except.op = FileOpRename;
+        except.title = tr("Rename file error");
         GError *err = nullptr;
         if (FileUtils::isFileExsit(g_file_get_uri(newFile.get()->get()))) {
             except.dlgType = ED_CONFLICT;
@@ -275,6 +278,13 @@ retry:
                 break;
             }
         }
+
+        char* newName = g_file_get_basename(newFile.get()->get());
+        g_file_set_display_name(file.get()->get(), newName, nullptr, &err);
+        if (nullptr != newName) {
+            g_free(newName);
+        }
+/*
         g_file_move(file.get()->get(),
                     newFile.get()->get(),
                     m_default_copy_flag,
@@ -282,9 +292,11 @@ retry:
                     nullptr,
                     nullptr,
                     &err);
+*/
         if (err) {
             except.errorType = ET_GIO;
             except.errorCode = err->code;
+            except.errorStr = err->message;
             auto responseType = Invalid;
             if (G_IO_ERROR_EXISTS != err->code) {
                 except.dlgType = ED_WARNING;
