@@ -54,8 +54,10 @@ retry:
             except.srcUri = src;
             except.destDirUri = tr("trash:///");
             except.isCritical = true;
-            except.title = tr("Trash file");
+            except.op = FileOpTrash;
+            except.title = tr("Trash file error");
             except.errorCode = err->code;
+            except.errorStr = err->message;
             except.errorType = ET_GIO;
             if (G_IO_ERROR_EXISTS == err->code) {
                 except.dlgType = ED_CONFLICT;
