@@ -45,7 +45,8 @@ FileWatcher::FileWatcher(QString uri, QObject *parent) : QObject(parent)
 
     connect(FileLabelModel::getGlobalModel(), &FileLabelModel::fileLabelChanged, this, [=](const QString &uri) {
         auto parentUri = FileUtils::getParentUri(uri);
-        if (parentUri == m_uri || parentUri == m_target_uri) {
+        QUrl parentUrl = parentUri;
+        if (parentUri == m_uri || parentUri == m_target_uri || parentUrl.toDisplayString() == m_uri || parentUrl.toDisplayString() == m_target_uri) {
             Q_EMIT fileChanged(uri);
             qDebug()<<"file label changed"<<uri;
         }
@@ -111,6 +112,7 @@ FileWatcher::~FileWatcher()
  */
 void FileWatcher::prepare()
 {
+    //FIXME: replace BLOCKING api in ui thread.
     GFileInfo *info = g_file_query_info(m_file,
                                         G_FILE_ATTRIBUTE_STANDARD_TARGET_URI,
                                         G_FILE_QUERY_INFO_NONE,
@@ -227,6 +229,12 @@ void FileWatcher::file_changed_callback(GFileMonitor *monitor,
     case G_FILE_MONITOR_EVENT_MOVED_IN:
     case G_FILE_MONITOR_EVENT_MOVED_OUT:
     case G_FILE_MONITOR_EVENT_RENAMED: {
+        /*!
+         * \bug
+         * renaming a desktop file can not get new uri correctly.
+         *
+         * we have to consider trigger it by another way.
+         */
         char *new_uri = g_file_get_uri(other_file);
         QString uri = new_uri;
         //QUrl url =  uri;
