@@ -34,12 +34,17 @@
 
 #include "gerror-wrapper.h"
 #include "bookmark-manager.h"
+#include "audio-play-manager.h"
 
 #include <QDebug>
 #include <QStandardPaths>
 
 #include <QMessageBox>
 #include <QUrl>
+#include <QTimer>
+#include <KWindowSystem>
+
+#include <QApplication>
 
 using namespace Peony;
 
@@ -85,15 +90,6 @@ FileItem::~FileItem()
     Q_EMIT cancelFindChildren();
     //disconnect();
 
-    if (m_info.use_count() <= 2) {
-        auto info = FileInfoManager::getInstance()->findFileInfoByUri(m_info->uri()).get();
-        if (info == m_info.get()) {
-            Peony::FileInfoManager::getInstance()->lock();
-            Peony::FileInfoManager::getInstance()->remove(m_info);
-            Peony::FileInfoManager::getInstance()->unlock();
-        }
-    }
-
     for (auto child : *m_children) {
         delete child;
     }
@@ -119,7 +115,7 @@ QVector<FileItem*> *FileItem::findChildrenSync()
     std::shared_ptr<Peony::FileEnumerator> enumerator = std::make_shared<Peony::FileEnumerator>();
     enumerator->setEnumerateDirectory(m_info->uri());
     enumerator->enumerateSync();
-    auto infos = enumerator->getChildren(true);
+    auto infos = enumerator->getChildren();
     for (auto info : infos) {
         FileItem *child = new FileItem(info, this, m_model);
         m_children->append(child);
@@ -127,12 +123,18 @@ QVector<FileItem*> *FileItem::findChildrenSync()
         job->setAutoDelete();
         job->querySync();
     }
+    //qDebug() << "FileItem findChildrenSync";
     Q_EMIT m_model->findChildrenFinished();
     return m_children;
 }
 
 void FileItem::findChildrenAsync()
 {
+    auto info = FileInfo::fromUri(m_info.get()->uri());
+    auto infoJob = new FileInfoJob(info);
+    infoJob->setAutoDelete();
+    infoJob->queryAsync();
+
     if (m_expanded)
         return;
 
@@ -145,6 +147,7 @@ void FileItem::findChildrenAsync()
     enumerator->connect(this, &FileItem::cancelFindChildren, enumerator, &FileEnumerator::cancel);
     enumerator->connect(enumerator, &FileEnumerator::prepared, this, [=](std::shared_ptr<GErrorWrapper> err, const QString &targetUri, bool critical) {
         if (critical) {
+            Peony::AudioPlayManager::getInstance()->playWarningAudio();
             QMessageBox::critical(nullptr, tr("Error"), err->message());
             enumerator->cancel();
             return;
@@ -157,7 +160,7 @@ void FileItem::findChildrenAsync()
                 GFile *targetFile = g_file_new_for_uri(targetUri.toUtf8().constData());
                 QUrl targetUrl = targetUri;
                 auto path = g_file_get_path(targetFile);
-                if (path && !targetUrl.isLocalFile()) {
+                if (path && !targetUrl.isLocalFile() && false) {
                     QString localUri = QString("file://%1").arg(path);
                     this->m_info = FileInfo::fromUri(localUri);
                     enumerator->setEnumerateDirectory(localUri);
@@ -173,6 +176,7 @@ void FileItem::findChildrenAsync()
             return;
         }
 
+        //FIXME: replace BLOCKING api in ui thread.
         auto target = FileUtils::getTargetUri(m_info->uri());
         if (!target.isEmpty()) {
             enumerator->cancel();
@@ -181,11 +185,20 @@ void FileItem::findChildrenAsync()
             return;
         }
         if (err) {
-            qDebug()<<err->message();
+            qDebug()<<"file item error:" <<err->message()<<enumerator->getEnumerateUri();
+            Peony::AudioPlayManager::getInstance()->playWarningAudio();
             if (err.get()->code() == G_IO_ERROR_NOT_FOUND || err.get()->code() == G_IO_ERROR_PERMISSION_DENIED) {
                 enumerator->cancel();
-                //enumerator->deleteLater();
-                m_model->setRootUri(FileUtils::getParentUri(this->uri()));
+                //fix goto removed path in case device is ejected
+                if (this->uri().startsWith("file:///media"))
+                {
+                    //check bookmark and delete
+                    BookMarkManager::getInstance()->removeBookMark(this->uri());
+                    m_model->setRootUri("computer:///");
+                }
+                else
+                    m_model->setRootUri(FileUtils::getParentUri(this->uri()));
+
                 auto fileInfo = FileInfo::fromUri(this->uri(), false);
                 if (err.get()->code() == G_IO_ERROR_NOT_FOUND && fileInfo->isSymbolLink())
                 {
@@ -198,8 +211,26 @@ void FileItem::findChildrenAsync()
                         FileOperationUtils::trash(selections, true);
                     }
                 }
+                else if (err.get()->code() == G_IO_ERROR_PERMISSION_DENIED)
+                {
+                    QMessageBox *msgBox = new QMessageBox();
+                    msgBox->setWindowTitle(tr("Error"));
+                    QString errorInfo = tr("Can not open path \"%1\"，permission denied.").arg(this->uri().unicode());
+                    msgBox->setText(errorInfo);
+                    msgBox->setModal(false);
+                    msgBox->setAttribute(Qt::WA_DeleteOnClose);
+                    KWindowSystem::setState(msgBox->winId(), KWindowSystem::KeepAbove);
+                    msgBox->show();
+                   //QMessageBox::critical(nullptr, tr("Error"), errorInfo);
+                }
+                else if(err.get()->code() == G_IO_ERROR_NOT_FOUND)
+                {
+                    QString errorInfo = tr("Can not find path \"%1\"，are you moved or renamed it?").arg(fileInfo->uri().unicode());
+                    QMessageBox::critical(nullptr, tr("Error"), errorInfo);
+                }
                 return;
-            } else {
+            }
+            else {
                 QMessageBox::critical(nullptr, tr("Error"), err->message());
                 enumerator->cancel();
                 return;
@@ -211,7 +242,7 @@ void FileItem::findChildrenAsync()
     if (!m_model->isPositiveResponse()) {
         enumerator->connect(enumerator, &Peony::FileEnumerator::enumerateFinished, this, [=](bool successed) {
             if (successed) {
-                auto infos = enumerator->getChildren(true);
+                auto infos = enumerator->getChildren();
                 m_async_count = infos.count();
                 if (infos.count() == 0) {
                     Q_EMIT m_model->findChildrenFinished();
@@ -251,6 +282,7 @@ void FileItem::findChildrenAsync()
                     job->queryAsync();
                 }
             } else {
+                //qDebug() << "enumerateFinished false" <<successed;
                 Q_EMIT m_model->findChildrenFinished();
                 return;
             }
@@ -286,9 +318,12 @@ void FileItem::findChildrenAsync()
                     connect(infoJob, &FileInfoJob::queryAsyncFinished, this, [=]() {
                         m_model->dataChanged(m_model->indexFromUri(uri), m_model->indexFromUri(uri));
                         auto info = FileInfo::fromUri(uri);
+                        ThumbnailManager::getInstance()->createThumbnail(uri, m_thumbnail_watcher, true);
+                        /*
                         if (info->isDesktopFile()) {
                             ThumbnailManager::getInstance()->updateDesktopFileThumbnail(info->uri(), m_thumbnail_watcher);
                         }
+                        */
                     });
                     infoJob->queryAsync();
                 }
@@ -318,9 +353,13 @@ void FileItem::findChildrenAsync()
             m_watcher->startMonitor();
         });
     } else {
-        enumerator->connect(enumerator, &Peony::FileEnumerator::childrenUpdated, this, [=](const QStringList &uris) {
+        enumerator->connect(enumerator, &Peony::FileEnumerator::childrenUpdated, this, [=](const QStringList &uris, bool isEnding) {
             if (uris.isEmpty()) {
-                Q_EMIT m_model->findChildrenFinished();
+                if (isEnding) {
+                    //qDebug() << "enumerateFinished childrenUpdated:" <<isEnding;
+                    Q_EMIT m_model->findChildrenFinished();
+                    Q_EMIT m_model->updated();
+                }
             }
 
             if (!m_children) {
@@ -329,31 +368,45 @@ void FileItem::findChildrenAsync()
                 return ;
             }
 
+            if (isEnding) {
+                m_ending_uris.clear();
+                m_ending_uris = uris;
+            }
             for (auto uri : uris) {
                 auto info = FileInfo::fromUri(uri);
-                auto item = new FileItem(info, this, m_model);
-                m_model->beginInsertRows(firstColumnIndex(), m_children->count(), m_children->count());
-                m_children->append(item);
-                m_model->endInsertRows();
                 auto infoJob = new FileInfoJob(info);
                 infoJob->setAutoDelete();
                 infoJob->connect(infoJob, &FileInfoJob::infoUpdated, this, [=]() {
-                    Q_EMIT m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
+                    auto item = new FileItem(info, this, m_model);
+                    m_model->beginInsertRows(firstColumnIndex(), m_children->count(), m_children->count());
+                    m_children->append(item);
+                    m_model->endInsertRows();
+                    //Q_EMIT m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
                     //Q_EMIT m_model->updated();
                     ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+
+                    m_ending_uris.removeOne(uri);
+                    if (isEnding && m_ending_uris.isEmpty()) {
+                        qApp->processEvents();
+                        Q_EMIT m_model->findChildrenFinished();
+                        Q_EMIT m_model->updated();
+                    }
                 });
                 infoJob->queryAsync();
             }
         });
 
-        enumerator->connect(enumerator, &Peony::FileEnumerator::enumerateFinished, this, [=]() {
+        enumerator->connect(enumerator, &Peony::FileEnumerator::enumerateFinished, this, [=](bool successed) {
             delete enumerator;
+
+            if (!successed) {
+                Q_EMIT m_model->findChildrenFinished();
+                return;
+            }
+
             if (!m_model||!m_children||!m_info)
                 return;
 
-            Q_EMIT m_model->findChildrenFinished();
-            Q_EMIT m_model->updated();
-
             m_watcher = std::make_shared<FileWatcher>(this->m_info->uri());
             m_watcher->setMonitorChildrenChange(true);
             connect(m_watcher.get(), &FileWatcher::fileCreated, this, [=](QString uri) {
@@ -456,13 +509,28 @@ void FileItem::onChildAdded(const QString &uri)
         //m_model->updated();
         return;
     }
-    FileItem *newChild = new FileItem(FileInfo::fromUri(uri), this, m_model);
-    m_model->beginInsertRows(this->firstColumnIndex(), m_children->count(), m_children->count());
-    m_children->append(newChild);
-    m_model->endInsertRows();
-    //use sync update here.
-    newChild->updateInfoAsync();
-    //m_model->updated();
+
+    auto info = FileInfo::fromUri(uri);
+    auto infoJob = new FileInfoJob(info);
+    infoJob->setAutoDelete();
+    infoJob->connect(infoJob, &FileInfoJob::infoUpdated, this, [=]() {
+        auto item = new FileItem(info, this, m_model);
+        m_model->beginInsertRows(firstColumnIndex(), m_children->count(), m_children->count());
+        m_children->append(item);
+        m_model->endInsertRows();
+        //Q_EMIT m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
+        //Q_EMIT m_model->updated();
+        ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+    });
+    infoJob->queryAsync();
+
+//    FileItem *newChild = new FileItem(FileInfo::fromUri(uri), this, m_model);
+//    m_model->beginInsertRows(this->firstColumnIndex(), m_children->count(), m_children->count());
+//    m_children->append(newChild);
+//    m_model->endInsertRows();
+//    //use sync update here.
+//    newChild->updateInfoAsync();
+//    //m_model->updated();
 }
 
 void FileItem::onChildRemoved(const QString &uri)
@@ -572,7 +640,7 @@ void FileItem::updateInfoSync()
     FileInfoJob *job = new FileInfoJob(m_info);
     if (job->querySync()) {
         m_model->dataChanged(this->firstColumnIndex(), this->lastColumnIndex());
-        ThumbnailManager::getInstance()->createThumbnail(this->uri(), m_thumbnail_watcher);
+        ThumbnailManager::getInstance()->createThumbnail(this->uri(), m_thumbnail_watcher, true);
     }
     job->deleteLater();
 }
@@ -583,7 +651,7 @@ void FileItem::updateInfoAsync()
     job->setAutoDelete();
     job->connect(job, &FileInfoJob::infoUpdated, this, [=]() {
         m_model->dataChanged(this->firstColumnIndex(), this->lastColumnIndex());
-        ThumbnailManager::getInstance()->createThumbnail(this->uri(), m_thumbnail_watcher);
+        ThumbnailManager::getInstance()->createThumbnail(this->uri(), m_thumbnail_watcher, true);
     });
     job->queryAsync();
 }
