@@ -24,6 +24,7 @@
 
 #include "file-meta-info.h"
 #include "file-info.h"
+#include "audio-play-manager.h"
 
 #include <QMessageBox>
 
@@ -108,6 +109,7 @@ void FileLabelModel::addLabel(const QString &label, const QColor &color)
     beginResetModel();
 
     if (getLabels().contains(label) || getColors().contains(color)) {
+        Peony::AudioPlayManager::getInstance()->playWarningAudio();
         QMessageBox::critical(nullptr, tr("Error"), tr("Label or color is duplicated."));
         return;
     }
@@ -330,6 +332,7 @@ bool FileLabelModel::setData(const QModelIndex &index, const QVariant &value, in
             return false;
         }
         if (getLabels().contains(name)) {
+            Peony::AudioPlayManager::getInstance()->playWarningAudio();
             QMessageBox::critical(nullptr, tr("Error"), tr("Label or color is duplicated."));
             return false;
         }
