@@ -35,6 +35,7 @@
 
 #include <QIcon>
 #include <QMessageBox>
+#include <QPushButton>
 #include <udisks/udisks.h>
 #include <sys/stat.h>
 
@@ -59,6 +60,7 @@ SideBarFileSystemItem::SideBarFileSystemItem(QString uri,
         //connect(m_watcher.get(), &FileWatcher::fileChanged, [=]())
     } else {
         m_uri = uri;
+        //FIXME: replace BLOCKING api in ui thread.
         m_display_name = FileUtils::getFileDisplayName(uri);
         m_icon_name = FileUtils::getFileIconName(uri);
         FileUtils::queryVolumeInfo(m_uri, m_volume_name, m_unix_device, m_display_name);
@@ -71,7 +73,7 @@ QString SideBarFileSystemItem::displayName()
     if (!m_volume_name.isEmpty()) {
         displayName += m_volume_name;
     }
-    if (!m_unix_device.isEmpty()) {
+    if (!m_unix_device.isEmpty() && !m_uri.contains("root.link")) {
         displayName += QString(" (%1)").arg(m_unix_device);
     }
     if (!displayName.isEmpty())
@@ -145,6 +147,7 @@ void SideBarFileSystemItem::findChildren()
                     m_model,
                     this);
             //check is mounted.
+            //FIXME: replace BLOCKING api in ui thread.
             auto targetUri = FileUtils::getTargetUri(info->uri());
             bool isUmountable = FileUtils::isFileUnmountable(info->uri());
             item->m_is_mounted = (!targetUri.isEmpty() && (targetUri != "file:///")) || isUmountable;
@@ -178,8 +181,9 @@ end:
         connect(m_watcher.get(), &FileWatcher::fileCreated, this, [=](const QString &uri) {
             //qDebug()<<"created:"<<uri;
             for (auto item : *m_children) {
-                if (item->uri() == uri)
+                if (item->uri() == uri) {
                     return;
+                }
             }
 
             SideBarFileSystemItem *item = new SideBarFileSystemItem(uri,
@@ -214,6 +218,7 @@ end:
             for (auto child : *m_children) {
                 if (child->uri() == uri) {
                     SideBarFileSystemItem *changedItem = static_cast<SideBarFileSystemItem*>(child);
+                    //FIXME: replace BLOCKING api in ui thread.
                     if (FileUtils::getTargetUri(uri).isEmpty()) {
                         changedItem->m_is_mounted = false;
                         changedItem->clearChildren();
@@ -223,6 +228,7 @@ end:
 
                     //why it would failed when send changed signal for newly mounted item?
                     //m_model->dataChanged(changedItem->firstColumnIndex(), changedItem->firstColumnIndex());
+                    updateFileInfo(changedItem);
                     m_model->dataChanged(changedItem->firstColumnIndex(), changedItem->lastColumnIndex());
                     break;
                 }
@@ -290,17 +296,38 @@ bool SideBarFileSystemItem::isMounted()
     return m_is_mounted;
 }
 
-void SideBarFileSystemItem::eject()
+void SideBarFileSystemItem::eject(GMountUnmountFlags ejectFlag)
 {
+    //FIXME: replace BLOCKING api in ui thread.
+    VolumeManager *volumeManager;
+    std::shared_ptr<Drive> drive;
+    GDrive *gdrive;
+
     auto file = wrapGFile(g_file_new_for_uri(this->uri().toUtf8().constData()));
     auto target = FileUtils::getTargetUri(m_uri);
-    auto drive = VolumeManager::getDriveFromUri(target);
-    g_file_eject_mountable_with_operation(file.get()->get(),
-                                          G_MOUNT_UNMOUNT_NONE,
+
+    volumeManager = VolumeManager::getInstance();
+    drive = volumeManager->getDriveFromUri(target);
+    if(!drive)
+        drive = volumeManager->getDriveFromSystemByPath(m_unix_device);
+
+    if(!drive)
+        return;
+
+    gdrive = drive->getGDrive();
+
+    if(g_drive_can_eject(gdrive)){//for udisk or DVD.
+        g_file_eject_mountable_with_operation(file.get()->get(),
+                                          ejectFlag,
                                           nullptr,
                                           nullptr,
                                           GAsyncReadyCallback(eject_cb),
                                           this);
+    }else if(g_drive_can_stop(gdrive)){//for mobile harddisk.
+        g_drive_stop(gdrive,ejectFlag,NULL,NULL,
+                     GAsyncReadyCallback(ejectDevicebyDrive),
+                     this);
+    }
 }
 
 static void unmount_force_cb(GFile* file, GAsyncResult* result, gpointer udata) {
@@ -427,8 +454,8 @@ void SideBarFileSystemItem::unmount()
 
 void SideBarFileSystemItem::ejectOrUnmount()
 {
-    if (isEjectable())
-        eject();
+    if (isRemoveable())
+        eject(G_MOUNT_UNMOUNT_NONE);
 
     else if (isMountable())
         unmount();
@@ -460,14 +487,60 @@ GAsyncReadyCallback SideBarFileSystemItem::eject_cb(GFile *file, GAsyncResult *r
     qDebug()<<successed;
     if (err) {
         qDebug()<<err->message;
+	/*fix #18957*/
+	QMessageBox warningBox(QMessageBox::Warning,QObject::tr("Eject failed"),QString(err->message));
+        QPushButton *cancelBtn = (warningBox.addButton(QObject::tr("Cancel"),QMessageBox::RejectRole));
+        QPushButton *ensureBtn = (warningBox.addButton(QObject::tr("Eject Anyway"),QMessageBox::YesRole));
+        warningBox.exec();
+        if(warningBox.clickedButton() == ensureBtn)
+            p_this->eject(G_MOUNT_UNMOUNT_FORCE);
+
         g_error_free(err);
     } else {
         // remove item anyway
-        int index = p_this->parent()->m_children->indexOf(p_this);
+        /*int index = p_this->parent()->m_children->indexOf(p_this);
         p_this->m_model->beginRemoveRows(p_this->parent()->firstColumnIndex(), index, index);
         p_this->parent()->m_children->removeOne(p_this);
         p_this->m_model->endRemoveRows();
-        p_this->deleteLater();
+        p_this->deleteLater();*/
     }
     return nullptr;
 }
+
+//update udisk file info
+void SideBarFileSystemItem::updateFileInfo(SideBarFileSystemItem *pThis){
+        QString tmpName = FileUtils::getFileDisplayName(pThis->m_uri);
+
+        //old's drive name -> now's volume name. fix #17968
+        FileUtils::queryVolumeInfo(pThis->m_uri,pThis->m_volume_name,pThis->m_unix_device,tmpName);
+        //icon name.
+        pThis->m_icon_name = FileUtils::getFileIconName(pThis->m_uri);
+        //mountable state. fix #19172
+        auto fileInfo = FileInfo::fromUri(pThis->m_uri,false);
+        FileInfoJob fileJob(fileInfo);
+        fileJob.querySync();
+}
+
+/* Eject some device by stop it's drive. Such as: mobile harddisk.
+ */
+void SideBarFileSystemItem::ejectDevicebyDrive(GObject* object,GAsyncResult* res,SideBarFileSystemItem *pThis)
+{
+    GError *error;
+    QString errorMsg;
+
+    error = NULL;
+    if(!g_drive_poll_for_media_finish(G_DRIVE(object),res,&error)){
+         if((NULL != error) && (G_IO_ERROR_FAILED_HANDLED != error->code)){
+             errorMsg = QObject::tr("Unable to eject %1").arg(pThis->m_display_name);
+
+             QMessageBox warningBox(QMessageBox::Warning,QObject::tr("Eject failed"),errorMsg);
+             QPushButton *cancelBtn = (warningBox.addButton(QObject::tr("Cancel"),QMessageBox::RejectRole));
+             QPushButton *ensureBtn = (warningBox.addButton(QObject::tr("Eject Anyway"),QMessageBox::YesRole));
+             warningBox.exec();
+             if(warningBox.clickedButton() == ensureBtn)
+                 pThis->eject(G_MOUNT_UNMOUNT_FORCE);
+
+             g_error_free(error);
+         }
+    }
+}
