@@ -193,8 +193,11 @@ QVariant SideBarModel::data(const QModelIndex &index, int role) const
 
     SideBarAbstractItem *item = static_cast<SideBarAbstractItem*>(index.internalPointer());
     if (index.column() == 1) {
-        if (role == Qt::DecorationRole && (item->isMounted()||item->isEjectable()))
-            return QVariant(QIcon::fromTheme("media-eject"));
+        if (role == Qt::DecorationRole && item->isRemoveable())
+            if (item->isMounted())
+                return QVariant(QIcon::fromTheme("media-eject"));
+            else//if volume has been unmounted,doesn't show icon.
+                return QVariant();
         else {
             return QVariant();
         }
@@ -335,6 +338,12 @@ bool SideBarModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
         for (auto url : data->urls()) {
             uris<<url.url();
         }
+
+        for(auto uri : uris)
+        {
+            if (uri.startsWith("trash://"))
+                return false;
+        }
         FileOperationUtils::move(uris, item->uri(), true, true);
         break;
     }
