@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +25,29 @@
 
 #include "peony-core_global.h"
 
+#include "vfs-plugin-iface.h"
+
 namespace Peony {
 
+class SearchVFSInternalPlugin : public VFSPluginIface
+{
+public:
+    SearchVFSInternalPlugin() {}
+
+    virtual PluginType pluginType() override {return VFSPlugin;}
+
+    virtual const QString name() override {return "search vfs";}
+    virtual const QString description() override {return QObject::tr("Default search vfs of peony");}
+    virtual const QIcon icon() override {return QIcon();}
+    virtual void setEnable(bool enable) {}
+    virtual bool isEnable() {return true;}
+
+    void initVFS() override;
+    QString uriScheme() override {return "search://";}
+    bool holdInSideBar() override {return false;}
+    void *parseUriToVFSFile(const QString &uri) override;
+};
+
 class PEONYCORESHARED_EXPORT SearchVFSRegister
 {
 public:
