@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,13 +24,15 @@
 #define SEARCHVFSURIPARSER_H
 
 #include <QString>
+#include <peony-core_global.h>
 
 namespace Peony {
 
-class SearchVFSUriParser
+class PEONYCORESHARED_EXPORT SearchVFSUriParser
 {
 public:
-    const static QString parseSearchKey(const QString &uri, const QString &key, const bool &search_file_name=true, const bool &search_content=false);
+    const static QString parseSearchKey(const QString &uri, const QString &key, const bool &search_file_name=true,
+                                        const bool &search_content=false, const QString &extend_key="", const bool &recursive = true);
     const static QString getSearchUriNameRegexp(const QString &searchUri);
     const static QString getSearchUriTargetDirectory(const QString &searchUri);
 private:
