@@ -54,6 +54,7 @@
 #include "file-meta-info.h"
 
 #include "global-settings.h"
+#include "audio-play-manager.h"
 
 #include <QAction>
 #include <QMouseEvent>
@@ -69,6 +70,7 @@
 
 #include <QStringList>
 #include <QMessageBox>
+#include <QDir>
 
 #include <QDebug>
 
@@ -113,7 +115,7 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
     setViewMode(QListView::IconMode);
     setMovement(QListView::Snap);
     setFlow(QListView::TopToBottom);
-    setResizeMode(QListView::Adjust);
+    setResizeMode(QListView::Fixed);
     setWordWrap(true);
 
     setDragDropMode(QListView::DragDrop);
@@ -154,6 +156,19 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
 
     m_proxy_model->setSourceModel(m_model);
 
+    connect(m_model, &QAbstractItemModel::rowsRemoved, this, [=](){
+        auto itemsNeedRelayout = m_model->m_items_need_relayout;
+        if (!itemsNeedRelayout.isEmpty()) {
+            this->relayoutExsitingItems(itemsNeedRelayout);
+        }
+
+        for (auto uri : getAllFileUris()) {
+            auto pos = getFileMetaInfoPos(uri);
+            if (pos.x() >= 0)
+                updateItemPosByUri(uri, pos);
+        }
+    });
+
     //connect(m_model, &DesktopItemModel::dataChanged, this, &DesktopIconView::clearAllIndexWidgets);
 
     connect(m_model, &DesktopItemModel::refreshed, this, [=]() {
@@ -222,20 +237,30 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
     setModel(m_proxy_model);
     //m_proxy_model->sort(0);
 
+    m_peonyDbusSer = new PeonyDbusService(this);
+    m_peonyDbusSer->dbusServerRegister();
+
     this->refresh();
 }
 
 DesktopIconView::~DesktopIconView()
 {
+    delete m_peonyDbusSer;
     //saveAllItemPosistionInfos();
 }
 
 bool DesktopIconView::eventFilter(QObject *obj, QEvent *e)
 {
     //fixme:
+    //comment to fix change night style refresh desktop issue
     if (e->type() == QEvent::StyleChange) {
-        if (m_model)
-            refresh();
+        if (m_model) {
+            for (auto uri : getAllFileUris()) {
+                auto pos = getFileMetaInfoPos(uri);
+                if (pos.x() >= 0)
+                    updateItemPosByUri(uri, pos);
+            }
+        }
     }
     return false;
 }
@@ -270,15 +295,13 @@ void DesktopIconView::initShoutCut()
     });
     addAction(pasteAction);
 
-    QAction *trashAction = new QAction(this);
-    trashAction->setShortcut(QKeySequence::Delete);
+    //add CTRL+D for delete operation
+    auto trashAction = new QAction(this);
+    trashAction->setShortcuts(QList<QKeySequence>()<<Qt::Key_Delete<<QKeySequence(Qt::CTRL + Qt::Key_D));
     connect(trashAction, &QAction::triggered, [=]() {
-        auto selectedUris = this->getSelections();
-        if (!selectedUris.isEmpty()) {
-            clearAllIndexWidgets();
-            auto op = new FileTrashOperation(selectedUris);
-            FileOperationManager::getInstance()->startOperation(op, true);
-        }
+        auto selectedUris = getSelections();
+        if (! selectedUris.isEmpty())
+           FileOperationUtils::trash(selectedUris, true);
     });
     addAction(trashAction);
 
@@ -286,6 +309,8 @@ void DesktopIconView::initShoutCut()
     undoAction->setShortcut(QKeySequence::Undo);
     connect(undoAction, &QAction::triggered,
     [=]() {
+        // do not relayout item with undo.
+        setRenaming(true);
         FileOperationManager::getInstance()->undo();
     });
     addAction(undoAction);
@@ -294,6 +319,8 @@ void DesktopIconView::initShoutCut()
     redoAction->setShortcut(QKeySequence::Redo);
     connect(redoAction, &QAction::triggered,
     [=]() {
+        // do not relayout item with redo.
+        setRenaming(true);
         FileOperationManager::getInstance()->redo();
     });
     addAction(redoAction);
@@ -342,10 +369,15 @@ void DesktopIconView::initShoutCut()
     propertiesWindowAction->setShortcuts(QList<QKeySequence>()<<QKeySequence(Qt::ALT + Qt::Key_Return)
                                          <<QKeySequence(Qt::ALT + Qt::Key_Enter));
     connect(propertiesWindowAction, &QAction::triggered, this, [=]() {
+        DesktopMenu menu(this);
         if (this->getSelections().count() > 0)
         {
-            PropertiesWindow *w = new PropertiesWindow(this->getSelections());
-            w->show();
+            menu.showProperties(this->getSelections());
+        }
+        else
+        {
+            QString desktopPath = "file://" +  QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+            menu.showProperties(desktopPath);
         }
     });
     addAction(propertiesWindowAction);
@@ -480,6 +512,30 @@ void DesktopIconView::openFileByUri(QString uri)
     job->setAutoDelete();
     job->connect(job, &FileInfoJob::queryAsyncFinished, [=]() {
         if ((info->isDir() || info->isVolume() || info->isVirtual())) {
+            QDir dir(info->filePath());
+            if (! dir.exists())
+            {
+                Peony::AudioPlayManager::getInstance()->playWarningAudio();
+                auto result = QMessageBox::question(nullptr, tr("Open Link failed"),
+                                      tr("File not exist, do you want to delete the link file?"));
+                if (result == QMessageBox::Yes) {
+                    qDebug() << "Delete unused symbollink in desktop.";
+                    QStringList selections;
+                    selections.push_back(uri);
+                    FileOperationUtils::trash(selections, true);
+                }
+                return;
+            }
+
+            if (! info->uri().startsWith("trash://")
+                    && ! info->uri().startsWith("computer://")
+                    &&  ! info->canExecute())
+            {
+                Peony::AudioPlayManager::getInstance()->playWarningAudio();
+                QMessageBox::critical(nullptr, tr("Open failed"),
+                                      tr("Open directory failed, you have no permission!"));
+                return;
+            }
 #if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
             QProcess p;
             QUrl url = uri;
@@ -509,9 +565,13 @@ void DesktopIconView::openFileByUri(QString uri)
 
 void DesktopIconView::initDoubleClick()
 {
-    connect(this, &QListView::doubleClicked, this, [=](const QModelIndex &index) {
+    connect(this, &QListView::activated, this, [=](const QModelIndex &index) {
         qDebug() << "double click" << index.data(FileItemModel::UriRole);
         auto uri = index.data(FileItemModel::UriRole).toString();
+        //process open symbolic link
+        auto info = FileInfo::fromUri(uri, false);
+        if (info->isSymbolLink() && uri.startsWith("file://") && info->isValid())
+            uri = "file://" + FileUtils::getSymbolicTarget(uri);
         openFileByUri(uri);
     }, Qt::UniqueConnection);
 }
@@ -610,7 +670,7 @@ void DesktopIconView::setFileMetaInfoPos(const QString &uri, const QPoint &pos)
     }
 }
 
-QHash<QString, QRect> DesktopIconView::getCurrentItemRects()
+QMap<QString, QRect> DesktopIconView::getCurrentItemRects()
 {
     return m_item_rect_hash;
 }
@@ -758,6 +818,27 @@ void DesktopIconView::wheelEvent(QWheelEvent *e)
 void DesktopIconView::keyPressEvent(QKeyEvent *e)
 {
     switch (e->key()) {
+    case Qt::Key_Home: {
+        auto boundingRect = getBoundingRect();
+        QRect homeRect = QRect(boundingRect.topLeft(), this->gridSize());
+        while (!indexAt(homeRect.center()).isValid()) {
+            homeRect.translate(0, gridSize().height());
+        }
+        auto homeIndex = indexAt(homeRect.center());
+        selectionModel()->select(homeIndex, QItemSelectionModel::SelectCurrent);
+        break;
+    }
+    case Qt::Key_End: {
+        auto boundingRect = getBoundingRect();
+        QRect endRect = QRect(boundingRect.bottomRight(), this->gridSize());
+        endRect.translate(-gridSize().width(), -gridSize().height());
+        while (!indexAt(endRect.center()).isValid()) {
+            endRect.translate(0, -gridSize().height());
+        }
+        auto endIndex = indexAt(endRect.center());
+        selectionModel()->select(endIndex, QItemSelectionModel::SelectCurrent);
+        break;
+    }
     case Qt::Key_Up: {
         if (getSelections().isEmpty()) {
             selectionModel()->select(model()->index(0, 0), QItemSelectionModel::SelectCurrent);
@@ -770,13 +851,17 @@ void DesktopIconView::keyPressEvent(QKeyEvent *e)
                 clearAllIndexWidgets();
                 selectionModel()->select(upIndex, QItemSelectionModel::SelectCurrent);
                 auto delegate = qobject_cast<DesktopIconViewDelegate *>(itemDelegate());
-                setIndexWidget(upIndex, new DesktopIndexWidget(delegate, viewOptions(), upIndex, this));
+                auto indexWidget = new DesktopIndexWidget(delegate, viewOptions(), upIndex, this);
+                setIndexWidget(upIndex, indexWidget);
+                indexWidget->move(visualRect(upIndex).topLeft());
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 for (auto uri : getAllFileUris()) {
                     auto pos = getFileMetaInfoPos(uri);
                     if (pos.x() >= 0)
                         updateItemPosByUri(uri, pos);
                 }
+#endif
             }
         }
         return;
@@ -793,13 +878,17 @@ void DesktopIconView::keyPressEvent(QKeyEvent *e)
                 clearAllIndexWidgets();
                 selectionModel()->select(downIndex, QItemSelectionModel::SelectCurrent);
                 auto delegate = qobject_cast<DesktopIconViewDelegate *>(itemDelegate());
-                setIndexWidget(downIndex, new DesktopIndexWidget(delegate, viewOptions(), downIndex, this));
+                auto indexWidget = new DesktopIndexWidget(delegate, viewOptions(), downIndex, this);
+                setIndexWidget(downIndex, indexWidget);
+                indexWidget->move(visualRect(downIndex).topLeft());
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 for (auto uri : getAllFileUris()) {
                     auto pos = getFileMetaInfoPos(uri);
                     if (pos.x() >= 0)
                         updateItemPosByUri(uri, pos);
                 }
+#endif
             }
         }
         return;
@@ -816,13 +905,16 @@ void DesktopIconView::keyPressEvent(QKeyEvent *e)
                 clearAllIndexWidgets();
                 selectionModel()->select(leftIndex, QItemSelectionModel::SelectCurrent);
                 auto delegate = qobject_cast<DesktopIconViewDelegate *>(itemDelegate());
-                setIndexWidget(leftIndex, new DesktopIndexWidget(delegate, viewOptions(), leftIndex, this));
-
+                auto indexWidget = new DesktopIndexWidget(delegate, viewOptions(), leftIndex, this);
+                setIndexWidget(leftIndex, indexWidget);
+                indexWidget->move(visualRect(leftIndex).topLeft());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 for (auto uri : getAllFileUris()) {
                     auto pos = getFileMetaInfoPos(uri);
                     if (pos.x() >= 0)
                         updateItemPosByUri(uri, pos);
                 }
+#endif
             }
         }
         return;
@@ -839,13 +931,15 @@ void DesktopIconView::keyPressEvent(QKeyEvent *e)
                 clearAllIndexWidgets();
                 selectionModel()->select(rightIndex, QItemSelectionModel::SelectCurrent);
                 auto delegate = qobject_cast<DesktopIconViewDelegate *>(itemDelegate());
-                setIndexWidget(rightIndex, new DesktopIndexWidget(delegate, viewOptions(), rightIndex, this));
-
+                auto indexWidget = new DesktopIndexWidget(delegate, viewOptions(), rightIndex, this);
+                setIndexWidget(rightIndex, indexWidget);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 for (auto uri : getAllFileUris()) {
                     auto pos = getFileMetaInfoPos(uri);
                     if (pos.x() >= 0)
                         updateItemPosByUri(uri, pos);
                 }
+#endif
             }
         }
         return;
@@ -884,7 +978,7 @@ void DesktopIconView::focusOutEvent(QFocusEvent *e)
 void DesktopIconView::resizeEvent(QResizeEvent *e)
 {
     QListView::resizeEvent(e);
-    refresh();
+    //refresh();
 }
 
 void DesktopIconView::rowsInserted(const QModelIndex &parent, int start, int end)
@@ -900,13 +994,13 @@ void DesktopIconView::rowsInserted(const QModelIndex &parent, int start, int end
 void DesktopIconView::rowsAboutToBeRemoved(const QModelIndex &parent, int start, int end)
 {
     QListView::rowsAboutToBeRemoved(parent, start, end);
-    QTimer::singleShot(1, this, [=](){
-        for (auto uri : getAllFileUris()) {
-            auto pos = getFileMetaInfoPos(uri);
-            if (pos.x() >= 0)
-                updateItemPosByUri(uri, pos);
-        }
-    });
+//    QTimer::singleShot(1, this, [=](){
+//        for (auto uri : getAllFileUris()) {
+//            auto pos = getFileMetaInfoPos(uri);
+//            if (pos.x() >= 0)
+//                updateItemPosByUri(uri, pos);
+//        }
+//    });
 }
 
 bool DesktopIconView::isItemsOverlapped()
@@ -935,6 +1029,78 @@ void DesktopIconView::setRenaming(bool renaming)
     m_is_renaming = renaming;
 }
 
+const QRect DesktopIconView::getBoundingRect()
+{
+    QRegion itemsRegion;
+    for (int i = 0; i < m_proxy_model->rowCount(); i++) {
+        auto index = m_proxy_model->index(i, 0);
+        QRect indexRect = QListView::visualRect(index);
+        itemsRegion += indexRect;
+    }
+    return itemsRegion.boundingRect();
+}
+
+void DesktopIconView::relayoutExsitingItems(const QStringList &uris)
+{
+    auto ensuredItemRectHash = m_item_rect_hash;
+    for (auto uri : uris) {
+        ensuredItemRectHash.remove(uri);
+    }
+
+    QRegion notEmptyRegion;
+    for (auto rect : ensuredItemRectHash.values()) {
+        notEmptyRegion += rect;
+    }
+
+    auto grid = this->gridSize();
+    auto viewRect = this->viewport()->rect();
+
+    // aligin exsited rect
+    int marginTop = notEmptyRegion.boundingRect().top();
+    while (marginTop - grid.height() > 0) {
+        marginTop -= grid.height();
+    }
+
+    int marginLeft = notEmptyRegion.boundingRect().left();
+    while (marginLeft - grid.width() > 0) {
+        marginLeft -= grid.width();
+    }
+
+    for (auto uri : uris) {
+        auto indexRect = QRect(QPoint(marginLeft, marginTop), m_item_rect_hash.values().first().size());
+        if (notEmptyRegion.contains(indexRect.center())) {
+
+            // move index to closest empty grid.
+            auto next = indexRect;
+            bool isEmptyPos = false;
+            while (!isEmptyPos) {
+                next.translate(0, grid.height());
+                if (next.bottom() > viewRect.bottom()) {
+                    int top = next.y();
+                    while (true) {
+                        if (top < grid.height()) {
+                            break;
+                        }
+                        top-=grid.height();
+                    }
+                    //put item to next column first row
+                    next.moveTo(next.x() + grid.width(), top);
+                }
+                if (notEmptyRegion.contains(next.center()))
+                    continue;
+
+                isEmptyPos = true;
+                m_item_rect_hash.insert(uri, next);
+                notEmptyRegion += next;
+
+                setFileMetaInfoPos(uri, next.topLeft());
+            }
+        } else {
+            setFileMetaInfoPos(uri, indexRect.topLeft());
+        }
+    }
+}
+
 void DesktopIconView::zoomOut()
 {
     clearAllIndexWidgets();
@@ -986,20 +1152,20 @@ void DesktopIconView::setDefaultZoomLevel(ZoomLevel level)
     switch (level) {
     case Small:
         setIconSize(QSize(24, 24));
-        setGridSize(QSize(64, 64));
+        setGridSize(QSize(64, 74));
         break;
     case Large:
         setIconSize(QSize(64, 64));
-        setGridSize(QSize(115, 135));
+        setGridSize(QSize(115, 145));
         break;
     case Huge:
         setIconSize(QSize(96, 96));
-        setGridSize(QSize(140, 170));
+        setGridSize(QSize(140, 180));
         break;
     default:
         m_zoom_level = Normal;
         setIconSize(QSize(48, 48));
-        setGridSize(QSize(96, 96));
+        setGridSize(QSize(96, 106));
         break;
     }
     clearAllIndexWidgets();
@@ -1047,6 +1213,11 @@ DesktopIconView::ZoomLevel DesktopIconView::zoomLevel() const
     return ZoomLevel(zoomLevel.toInt()) == Invalid? Normal: ZoomLevel(QString(zoomLevel).toInt());
 }
 
+void DesktopIconView::setEditFlag(bool edit)
+{
+    m_is_edit = edit;
+}
+
 void DesktopIconView::mousePressEvent(QMouseEvent *e)
 {
     // bug extend selection bug
@@ -1058,17 +1229,22 @@ void DesktopIconView::mousePressEvent(QMouseEvent *e)
             clearSelection();
         } else {
             auto index = indexAt(e->pos());
-            clearAllIndexWidgets();
+            //fix rename state has no menuRequest issue
+            if (! m_is_edit)
+               clearAllIndexWidgets();
             m_last_index = index;
             if (!indexWidget(m_last_index)) {
+                auto indexWidget = new DesktopIndexWidget(qobject_cast<DesktopIconViewDelegate *>(itemDelegate()), viewOptions(), m_last_index);
                 setIndexWidget(m_last_index,
-                               new DesktopIndexWidget(qobject_cast<DesktopIconViewDelegate *>(itemDelegate()), viewOptions(), m_last_index));
-
+                               indexWidget);
+                indexWidget->move(visualRect(m_last_index).topLeft());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 for (auto uri : getAllFileUris()) {
                     auto pos = getFileMetaInfoPos(uri);
                     if (pos.x() >= 0)
                         updateItemPosByUri(uri, pos);
                 }
+#endif
             }
         }
     }
@@ -1084,6 +1260,8 @@ void DesktopIconView::mousePressEvent(QMouseEvent *e)
 void DesktopIconView::mouseReleaseEvent(QMouseEvent *e)
 {
     QListView::mouseReleaseEvent(e);
+
+    this->viewport()->update(viewport()->rect());
 }
 
 void DesktopIconView::mouseDoubleClickEvent(QMouseEvent *event)
@@ -1153,33 +1331,33 @@ void DesktopIconView::dropEvent(QDropEvent *e)
       is incorrect.
       */
     m_edit_trigger_timer.stop();
-    if (e->keyboardModifiers() && Qt::ControlModifier)
+    if (e->keyboardModifiers() & Qt::ControlModifier) {
         m_ctrl_key_pressed = true;
-    else
+    } else {
         m_ctrl_key_pressed = false;
+    }
 
     auto action = m_ctrl_key_pressed ? Qt::CopyAction : Qt::MoveAction;
     qDebug() << "DesktopIconView dropEvent" <<action;
-    if (this == e->source() && !m_ctrl_key_pressed)
-    {
+    if (this == e->source() && !m_ctrl_key_pressed) {
         auto index = indexAt(e->pos());
         qDebug() <<"DesktopIconView index:" <<index <<index.isValid();
         bool bmoved = false;
         if (index.isValid()) {
             auto info = FileInfo::fromUri(index.data(Qt::UserRole).toString());
-            if (!info->isDir())
+            if (!info->isDir()) {
                 return;
+            }
             bmoved = true;
         }
 
-        if (bmoved)
-        {
+        if (bmoved) {
             //move file to desktop folder
             qDebug() << "DesktopIconView move file to folder";
             m_model->dropMimeData(e->mimeData(), action, -1, -1, this->indexAt(e->pos()));
-        }
-        else
+        } else {
             QListView::dropEvent(e);
+        }
 
         QHash<QModelIndex, QRect> currentIndexesRects;
         for (int i = 0; i < m_proxy_model->rowCount(); i++) {
@@ -1205,7 +1383,7 @@ void DesktopIconView::dropEvent(QDropEvent *e)
 
             for (auto index : unoverlappedIndexes) {
                 // save pos
-                QTimer::singleShot(1, this, [=](){
+                QTimer::singleShot(1, this, [=]() {
                     setFileMetaInfoPos(index.data(Qt::UserRole).toString(), QListView::visualRect(index).topLeft());
                 });
             }
@@ -1237,10 +1415,12 @@ void DesktopIconView::dropEvent(QDropEvent *e)
                             //put item to next column first column
                             next.moveTo(next.x() + grid.width(), top);
                         }
-                        if (notEmptyRegion.contains(next.center()))
+                        if (notEmptyRegion.contains(next.center())) {
                             continue;
+                        }
 
                         isEmptyPos = true;
+
                         setPositionForIndex(next.topLeft(), dragedIndex);
                         setFileMetaInfoPos(dragedIndex.data(Qt::UserRole).toString(), next.topLeft());
                         notEmptyRegion += next;
@@ -1251,23 +1431,27 @@ void DesktopIconView::dropEvent(QDropEvent *e)
             // check if there is any item out of view
             for (auto index : m_drag_indexes) {
                 auto indexRect = QListView::visualRect(index);
-                if (this->viewport()->rect().contains(indexRect.center())) {
+                if (this->viewport()->rect().contains(indexRect)) {
                     continue;
                 }
 
                 // try relocating invisible item
-
-                QRect next;
-                for (auto existedRect : notEmptyRegion.rects()) {
-                    if (this->viewport()->rect().contains(existedRect)) {
-                        next = existedRect;
+                QRect next(0, 0, 0, 0);
+                for (auto existedRect = notEmptyRegion.begin(); existedRect != notEmptyRegion.end(); ++existedRect) {
+                    if (this->viewport()->rect().contains(*existedRect)) {
+                        next = *existedRect;
                         break;
+                    } else if (existedRect == notEmptyRegion.end() - 1
+                               && next == QRect(0, 0, 0, 0)) {
+                        next = *existedRect;
+                        next.moveTo(0, 0);
                     }
                 }
-                while (next.translated(-grid.width(), 0).x() > 0) {
+
+                while (next.translated(-grid.width(), 0).x() >= 0) {
                     next.translate(-grid.width(), 0);
                 }
-                while (next.translated(0, -grid.height()).top() > 0) {
+                while (next.translated(0, -grid.height()).top() >= 0) {
                     next.translate(0, -grid.height());
                 }
 
@@ -1381,3 +1565,14 @@ QRect DesktopIconView::visualRect(const QModelIndex &index) const
     rect.moveTo(rect.topLeft() + p);
     return rect;
 }
+
+int DesktopIconView::updateBWList()
+{
+    m_proxy_model->updateBlackAndWriteLists();
+    /*
+    * 重新按照既定规则排序，这样可以避免出现空缺和图标重叠的情况
+    */
+    int sortType = GlobalSettings::getInstance()->getValue(LAST_DESKTOP_SORT_ORDER).toInt();
+    setSortType(sortType);
+    return 0;
+}
