@@ -57,6 +57,11 @@ using namespace Peony;
 DesktopItemModel::DesktopItemModel(QObject *parent)
     : QAbstractListModel(parent)
 {
+    // do not redo layout new items while we start an operation with peony's api.
+    connect(FileOperationManager::getInstance(), &FileOperationManager::operationStarted, this, [=](){
+        m_new_file_info_query_queue.clear();
+    });
+
     m_thumbnail_watcher = std::make_shared<FileWatcher>("thumbnail:///, this");
 
     connect(m_thumbnail_watcher.get(), &FileWatcher::fileChanged, this, [=](const QString &uri) {
@@ -100,15 +105,6 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
     m_desktop_watcher->setMonitorChildrenChange(true);
     this->connect(m_desktop_watcher.get(), &FileWatcher::fileCreated, [=](const QString &uri) {
         qDebug()<<"desktop file created"<<uri;
-        
-        //refresh the desktop ,let file can be see at once
-        //Q_EMIT this->refresh();
-
-        if (m_new_file_info_query_queue.contains(uri)) {
-            return;
-        } else {
-            m_new_file_info_query_queue<<uri;
-        }
 
         auto info = FileInfo::fromUri(uri, true);
         bool exsited = false;
@@ -119,90 +115,39 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
             }
         }
 
+        if (m_new_file_info_query_queue.contains(uri)) {
+            exsited = true;
+        } else {
+            m_new_file_info_query_queue<<uri;
+        }
+
         if (!exsited) {
             auto job = new FileInfoJob(info);
             job->setAutoDelete();
-            connect(job, &FileInfoJob::infoUpdated, [=]() {
-                // locate new item =====
+            job->querySync();
 
-                auto view = PeonyDesktopApplication::getIconView();
-                auto itemRectHash = view->getCurrentItemRects();
-                auto grid = view->gridSize();
-                auto viewRect = view->rect();
+            // locate new item =====
 
-                QRegion notEmptyRegion;
-                for (auto rect : itemRectHash.values()) {
-                    notEmptyRegion += rect;
-                }
+            auto view = PeonyDesktopApplication::getIconView();
+            auto itemRectHash = view->getCurrentItemRects();
+            auto grid = view->gridSize();
+            auto viewRect = view->rect();
 
-                if (!view->isRenaming()) {
-                    view->setFileMetaInfoPos(uri, QPoint(-1, -1));
-                } else {
-                    view->setRenaming(false);
-                }
+            QRegion notEmptyRegion;
+            for (auto rect : itemRectHash.values()) {
+                notEmptyRegion += rect;
+            }
 
-                auto metaInfoPos = view->getFileMetaInfoPos(uri);
-                if (metaInfoPos.x() >= 0) {
-                    // check if overlapped, it might happend whild drag out and in desktop view.
-                    auto indexRect = QRect(metaInfoPos, itemRectHash.values().first().size());
-                    if (notEmptyRegion.contains(indexRect.center())) {
+            if (!view->isRenaming()) {
+                view->setFileMetaInfoPos(uri, QPoint(-1, -1));
+            } else {
+                view->setRenaming(false);
+            }
 
-                        // move index to closest empty grid.
-                        auto next = indexRect;
-                        bool isEmptyPos = false;
-                        while (!isEmptyPos) {
-                            next.translate(0, grid.height());
-                            if (next.bottom() > viewRect.bottom()) {
-                                int top = next.y();
-                                while (true) {
-                                    if (top < grid.height()) {
-                                        break;
-                                    }
-                                    top-=grid.height();
-                                }
-                                //put item to next column first row
-                                next.moveTo(next.x() + grid.width(), top);
-                            }
-                            if (notEmptyRegion.contains(next.center()))
-                                continue;
-
-                            isEmptyPos = true;
-                            itemRectHash.insert(info->uri(), next);
-                            notEmptyRegion += next;
-
-                            // handle position locate in DesktopIconView::itemInserted().
-                            view->setFileMetaInfoPos(info->uri(), next.topLeft());
-                        }
-                    }
-
-                    this->beginInsertRows(QModelIndex(), m_files.count(), m_files.count());
-                    ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
-                    m_files<<info;
-                    //this->insertRows(m_files.indexOf(info), 1);
-                    this->endInsertRows();
-                    m_new_file_info_query_queue.removeOne(uri);
-
-                    // end locate new item=======
-
-                    //this->endResetModel();
-                    Q_EMIT this->requestUpdateItemPositions();
-                    Q_EMIT this->requestLayoutNewItem(info->uri());
-                    Q_EMIT this->fileCreated(uri);
-                    return;
-                }
-
-                // aligin exsited rect
-                int marginTop = notEmptyRegion.boundingRect().top();
-                while (marginTop - grid.height() > 0) {
-                    marginTop -= grid.height();
-                }
-
-                int marginLeft = notEmptyRegion.boundingRect().left();
-                while (marginLeft - grid.width() > 0) {
-                    marginLeft -= grid.width();
-                }
-
-                auto indexRect = QRect(QPoint(marginLeft, marginTop), itemRectHash.isEmpty()? QSize(): itemRectHash.values().first().size());
+            auto metaInfoPos = view->getFileMetaInfoPos(uri);
+            if (metaInfoPos.x() >= 0) {
+                // check if overlapped, it might happend whild drag out and in desktop view.
+                auto indexRect = QRect(metaInfoPos, itemRectHash.values().first().size());
                 if (notEmptyRegion.contains(indexRect.center())) {
 
                     // move index to closest empty grid.
@@ -228,28 +173,16 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                         itemRectHash.insert(info->uri(), next);
                         notEmptyRegion += next;
 
+                        // handle position locate in DesktopIconView::itemInserted().
                         view->setFileMetaInfoPos(info->uri(), next.topLeft());
                     }
-                } else {
-                    view->setFileMetaInfoPos(info->uri(), indexRect.topLeft());
-                    QTimer::singleShot(1, view, [=](){
-                        //view->updateItemPosByUri(uri, indexRect.topLeft());
-                    });
                 }
 
-                //this->beginResetModel();
                 this->beginInsertRows(QModelIndex(), m_files.count(), m_files.count());
                 ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
                 m_files<<info;
                 //this->insertRows(m_files.indexOf(info), 1);
                 this->endInsertRows();
-                m_new_file_info_query_queue.removeOne(uri);
-
-                QTimer::singleShot(1, this, [=](){
-                    for (auto key : itemRectHash.keys()) {
-                        view->updateItemPosByUri(key, itemRectHash.value(key).topLeft());
-                    }
-                });
 
                 // end locate new item=======
 
@@ -257,12 +190,81 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                 Q_EMIT this->requestUpdateItemPositions();
                 Q_EMIT this->requestLayoutNewItem(info->uri());
                 Q_EMIT this->fileCreated(uri);
-            });
-            job->queryAsync();
+                return;
+            }
+
+            // aligin exsited rect
+            int marginTop = notEmptyRegion.boundingRect().top();
+            while (marginTop - grid.height() > 0) {
+                marginTop -= grid.height();
+            }
+
+            int marginLeft = notEmptyRegion.boundingRect().left();
+            while (marginLeft - grid.width() > 0) {
+                marginLeft -= grid.width();
+            }
+
+            auto indexRect = QRect(QPoint(marginLeft, marginTop), itemRectHash.isEmpty()? QSize(): itemRectHash.values().first().size());
+            if (notEmptyRegion.contains(indexRect.center())) {
+
+                // move index to closest empty grid.
+                auto next = indexRect;
+                bool isEmptyPos = false;
+                while (!isEmptyPos) {
+                    next.translate(0, grid.height());
+                    if (next.bottom() > viewRect.bottom()) {
+                        int top = next.y();
+                        while (true) {
+                            if (top < grid.height()) {
+                                break;
+                            }
+                            top-=grid.height();
+                        }
+                        //put item to next column first row
+                        next.moveTo(next.x() + grid.width(), top);
+                    }
+                    if (notEmptyRegion.contains(next.center()))
+                        continue;
+
+                    isEmptyPos = true;
+                    itemRectHash.insert(info->uri(), next);
+                    notEmptyRegion += next;
+
+                    view->setFileMetaInfoPos(info->uri(), next.topLeft());
+                }
+            } else {
+                view->setFileMetaInfoPos(info->uri(), indexRect.topLeft());
+            }
+
+            //this->beginResetModel();
+            this->beginInsertRows(QModelIndex(), m_files.count(), m_files.count());
+            ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+            m_files<<info;
+            //this->insertRows(m_files.indexOf(info), 1);
+            this->endInsertRows();
+
+            // end locate new item=======
+
+            //this->endResetModel();
+            Q_EMIT this->requestUpdateItemPositions();
+            Q_EMIT this->requestLayoutNewItem(info->uri());
+            Q_EMIT this->fileCreated(uri);
         }
     });
 
     this->connect(m_desktop_watcher.get(), &FileWatcher::fileDeleted, [=](const QString &uri) {
+        // try relayout floating items, it's often occurred when unarchive a archive file, or modify a file with vim outside of peony.
+        m_last_deleted_item_uri = uri;
+        int index = m_new_file_info_query_queue.indexOf(uri);
+        if (index >= 0) {
+            m_items_need_relayout = m_new_file_info_query_queue;
+            for (int i = 0; i <= index; i++) {
+                m_items_need_relayout.removeFirst();
+            }
+        } else {
+            m_items_need_relayout.clear();
+        }
+        m_new_file_info_query_queue.removeOne(uri);
         auto view = PeonyDesktopApplication::getIconView();
         view->removeItemRect(uri);
 
@@ -277,15 +279,8 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                 //this->endResetModel();
                 Q_EMIT this->requestClearIndexWidget();
                 Q_EMIT this->requestUpdateItemPositions();
-                FileInfoManager::getInstance()->remove(info);
             }
         }
-
-        QTimer::singleShot(1, this, [=](){
-            for (auto key : itemRectHash.keys()) {
-                view->updateItemPosByUri(key, itemRectHash.value(key).topLeft());
-            }
-        });
     });
 
     this->connect(m_desktop_watcher.get(), &FileWatcher::fileChanged, [=](const QString &uri) {
@@ -331,7 +326,6 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                     //this->endResetModel();
                     Q_EMIT this->requestClearIndexWidget();
                     Q_EMIT this->requestUpdateItemPositions();
-                    FileInfoManager::getInstance()->remove(info);
                     QStringList list;
                     list.append(info->uri());
                     FileOperationUtils::trash(list, false);
@@ -362,7 +356,6 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                     //this->endResetModel();
                     Q_EMIT this->requestClearIndexWidget();
                     Q_EMIT this->requestUpdateItemPositions();
-                    FileInfoManager::getInstance()->remove(info);
                     QStringList list;
                     list.append(info->uri());
                     FileOperationUtils::trash(list, false);
@@ -374,7 +367,7 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
 
 DesktopItemModel::~DesktopItemModel()
 {
-    FileInfoManager::getInstance()->clear();
+
 }
 
 void DesktopItemModel::refresh()
@@ -382,7 +375,6 @@ void DesktopItemModel::refresh()
     ThumbnailManager::getInstance()->syncThumbnailPreferences();
     beginResetModel();
     //removeRows(0, m_files.count());
-    FileInfoManager::getInstance()->clear();
     //m_trash_watcher->stopMonitor();
     //m_desktop_watcher->stopMonitor();
     for (auto info : m_files) {
@@ -391,8 +383,10 @@ void DesktopItemModel::refresh()
     m_files.clear();
 
     auto desktopUri = "file://" + QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+    //FIXME: replace BLOCKING api in ui thread.
     if (!FileUtils::isFileExsit(desktopUri)) {
         // try get correct desktop path delay.
+        //FIXME: replace BLOCKING api in ui thread.
         QTimer::singleShot(1000, this, [=](){
             if (!FileUtils::isFileExsit(desktopUri)) {
                 endResetModel();
@@ -462,7 +456,6 @@ QVariant DesktopItemModel::data(const QModelIndex &index, int role) const
 void DesktopItemModel::onEnumerateFinished()
 {
     //beginResetModel();
-    FileInfoManager::getInstance()->clear();
     beginRemoveRows(QModelIndex(), 0, m_files.count() - 1);
     m_files.clear();
     endRemoveRows();
@@ -477,19 +470,23 @@ void DesktopItemModel::onEnumerateFinished()
     infos<<trash;
     infos<<personal;
 
-    infos<<m_enumerator->getChildren(true);
+    infos<<m_enumerator->getChildren();
 
     //qDebug()<<m_files.count();
     //this->endResetModel();
     for (auto info : infos) {
-        m_info_query_queue<<info->uri();
         beginInsertRows(QModelIndex(), m_files.count(), m_files.count());
         auto syncJob = new FileInfoJob(info);
         syncJob->querySync();
         syncJob->deleteLater();
         m_files<<info;
         endInsertRows();
-        ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+
+        if (info->isDesktopFile()) {
+            ThumbnailManager::getInstance()->updateDesktopFileThumbnail(info->uri(), m_thumbnail_watcher);
+        } else {
+            ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+        }
     }
     for (auto info : m_files) {
         auto uri = info->uri();
