@@ -24,6 +24,8 @@
 #define DESKTOPITEMPROXYMODEL_H
 
 #include <QSortFilterProxyModel>
+#include "bw-list-info.h"
+#include "peony-json-operation.h"
 
 namespace Peony {
 
@@ -33,12 +35,13 @@ class DesktopItemProxyModel : public QSortFilterProxyModel
 public:
     enum SortType {
         FileName,
+        ModifiedDate,
         FileType,
         FileSize,
-        ModifiedDate,
         Other
     };
     explicit DesktopItemProxyModel(QObject *parent = nullptr);
+    ~DesktopItemProxyModel();
 
     void setSortType(int type) {
         m_sort_type = type;
@@ -48,6 +51,7 @@ public:
     }
 
     void setShowHidden(bool showHidden);
+    int updateBlackAndWriteLists();
 
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
     bool lessThan(const QModelIndex &source_left, const QModelIndex &source_right) const;
@@ -55,6 +59,9 @@ public:
 private:
     int m_sort_type = Other;
     bool m_show_hidden;
+
+    BWListInfo    *m_bwListInfo;
+    PeonyJsonOperation *m_jsonOp;
 };
 
 }
