@@ -39,6 +39,7 @@
 #include "desktop-menu-plugin-manager.h"
 
 #include "global-settings.h"
+#include "audio-play-manager.h"
 
 #include <QProcess>
 #include <QStandardPaths>
@@ -46,6 +47,7 @@
 
 #include <QUrl>
 #include <QDir>
+#include <QStandardPaths>
 
 using namespace Peony;
 
@@ -113,9 +115,13 @@ const QList<QAction *> DesktopMenu::constructOpenOpActions()
             m_view->invertSelections();
         });
     } else {
-        if (m_selections.count() == 1) {
+        if (m_selections.count() == 1
+                && !m_selections.first().startsWith("trash://")
+                && !m_selections.first().startsWith("computer://")
+                && (m_selections.first() != ("file://" + QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first()))) {
             auto info = FileInfo::fromUri(m_selections.first());
             auto displayName = info->displayName();
+            //FIXME: replace BLOCKING api in ui thread.
             if (displayName.isEmpty())
                 displayName = FileUtils::getFileDisplayName(info->uri());
             //when name is too long, show elideText
@@ -182,9 +188,17 @@ const QList<QAction *> DesktopMenu::constructOpenOpActions()
                 });
             }
         } else {
-            l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("&Open %1 selected files").arg(m_selections.count()));
+            if (m_selections.count() == 1)
+            {
+                auto info = FileInfo::fromUri(m_selections.first());
+                auto displayName = info->displayName();
+                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("&Open \"%1\"").arg(displayName));
+            }
+            else
+                l<<addAction(QIcon::fromTheme("document-open-symbolic"), tr("&Open %1 selected files").arg(m_selections.count()));
+
             connect(l.last(), &QAction::triggered, [=]() {
-                qDebug()<<"triggered";
+                qDebug()<<"triggered:"<<m_selections.count();
                 QStringList dirs;
                 QStringList files;
                 for (auto uri : m_selections) {
@@ -356,9 +370,9 @@ const QList<QAction *> DesktopMenu::constructViewOpActions()
 
         QList<QAction *> tmp;
         tmp<<sortTypeMenu->addAction(tr("Name"));
+        tmp<<sortTypeMenu->addAction(tr("Modified Date"));
         tmp<<sortTypeMenu->addAction(tr("File Type"));
         tmp<<sortTypeMenu->addAction(tr("File Size"));
-        tmp<<sortTypeMenu->addAction(tr("Modified Date"));
 
         int sortType = m_view->getSortType();
         qDebug() << "sortType:" <<sortType <<tmp.count();
@@ -425,11 +439,13 @@ const QList<QAction *> DesktopMenu::constructFileOpActions()
             e.setEnumerateDirectory("trash:///");
             e.enumerateSync();
             auto trashChildren = e.getChildrenUris();
-            l<<addAction(QIcon::fromTheme("view-refresh-symbolic"), tr("&Restore all"), [=]() {
-                FileOperationUtils::restore(trashChildren);
-            });
-            l.last()->setEnabled(!trashChildren.isEmpty());
+            //comment to avoid uncorrect operation in desktop, only in trash can do it
+//            l<<addAction(QIcon::fromTheme("view-refresh-symbolic"), tr("&Restore all"), [=]() {
+//                FileOperationUtils::restore(trashChildren);
+//            });
+//            l.last()->setEnabled(!trashChildren.isEmpty());
             l<<addAction(QIcon::fromTheme("edit-clear-symbolic"), tr("&Clean the trash"), [=]() {
+                Peony::AudioPlayManager::getInstance()->playWarningAudio();
                 auto result = QMessageBox::question(nullptr, tr("Delete Permanently"), tr("Are you sure that you want to delete these files? "
                                                     "Once you start a deletion, the files deleting will never be "
                                                     "restored again."));
@@ -456,11 +472,12 @@ const QList<QAction *> DesktopMenu::constructFileOpActions()
                 connect(l.last(), &QAction::triggered, [=]() {
                     FileOperationUtils::trash(m_selections, true);
                 });
+                //comment delete forever right menu option,reference to mac and Windows
                 //add delete forever option
-                l<<addAction(QIcon::fromTheme("edit-clear-symbolic"), tr("Delete forever"));
-                connect(l.last(), &QAction::triggered, [=]() {
-                    FileOperationUtils::executeRemoveActionWithDialog(m_selections);
-                });
+//                l<<addAction(QIcon::fromTheme("edit-clear-symbolic"), tr("Delete forever"));
+//                connect(l.last(), &QAction::triggered, [=]() {
+//                    FileOperationUtils::executeRemoveActionWithDialog(m_selections);
+//                });
             }
 
             if (m_selections.count() == 1) {
