@@ -27,10 +27,13 @@
 
 #include "singleapplication.h"
 #include "desktop-window.h"
+#include "volume-manager.h"
 
 #include <QScreen>
 #include <QWindow>
 
+using namespace Peony;
+
 class PeonyDesktopApplication : public SingleApplication
 {
     Q_OBJECT
@@ -41,6 +44,8 @@ public:
     static bool userGuideDaemonRunning();
     static void showGuide(const QString &appName = "");
 
+    static qint64 peony_desktop_start_time;
+
 protected Q_SLOTS:
     void parseCmd(quint32 id, QByteArray msg, bool isPrimary);
     bool isPrimaryScreen(QScreen *screen);
@@ -50,6 +55,7 @@ public Q_SLOTS:
     void primaryScreenChangedProcess(QScreen *screen);
     void screenAddedProcess(QScreen *screen);
     void screenRemovedProcess(QScreen *screen);
+    void volumeRemovedProcess(const std::shared_ptr<Peony::Volume> &volume);
 
     void addWindow(QScreen *screen, bool checkPrimay = true);
     void changeBgProcess(const QString& bgPath);
