@@ -49,16 +49,25 @@
 #include <QEvent>
 #include <QApplication>
 #include <QTimer>
+#include <QStandardPaths>
 
 #include <KWindowSystem>
 
+#include <QtConcurrent>
+
 #include <QDebug>
 
 static HeaderBarStyle *global_instance = nullptr;
 static QString terminal_cmd = nullptr;
 
+static QString gPlatform = nullptr;
+
 HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
 {
+    if (gPlatform.isNull()) {
+        gPlatform = qgetenv("XDG_SESSION_TYPE");
+    }
+
     setAttribute(Qt::WA_AcceptTouchEvents);
 
     setMouseTracking(true);
@@ -170,7 +179,7 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     viewType->setPopupMode(QToolButton::InstantPopup);
 
     m_view_type_menu = new ViewTypeMenu(viewType);
-    viewType->setMenu(m_view_type_menu);
+    a->setMenu(m_view_type_menu);
 
     connect(m_view_type_menu, &ViewTypeMenu::switchViewRequest, this, [=](const QString &id, const QIcon &icon, bool resetToZoomLevel) {
         viewType->setText(id);
@@ -197,7 +206,7 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     sortType->setPopupMode(QToolButton::InstantPopup);
 
     m_sort_type_menu = new SortTypeMenu(this);
-    sortType->setMenu(m_sort_type_menu);
+    a->setMenu(m_sort_type_menu);
 
     connect(m_sort_type_menu, &SortTypeMenu::switchSortTypeRequest, m_window, &MainWindow::setCurrentSortColumn);
     connect(m_sort_type_menu, &SortTypeMenu::switchSortOrderRequest, m_window, [=](Qt::SortOrder order) {
@@ -224,7 +233,7 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     popMenu->setPopupMode(QToolButton::InstantPopup);
 
     m_operation_menu = new OperationMenu(m_window, this);
-    popMenu->setMenu(m_operation_menu);
+    a->setMenu(m_operation_menu);
 
     for (auto action : actions()) {
         auto w = widgetForAction(action);
@@ -235,20 +244,22 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
 
 void HeaderBar::findDefaultTerminal()
 {
-    GList *infos = g_app_info_get_all();
-    GList *l = infos;
-    while (l) {
-        const char *cmd = g_app_info_get_executable(static_cast<GAppInfo*>(l->data));
-        QString tmp = cmd;
-        if (tmp.contains("terminal")) {
-            terminal_cmd = tmp;
-            if (tmp == "mate-terminal") {
-                break;
+    QtConcurrent::run([](){
+        GList *infos = g_app_info_get_all();
+        GList *l = infos;
+        while (l) {
+            const char *cmd = g_app_info_get_executable(static_cast<GAppInfo*>(l->data));
+            QString tmp = cmd;
+            if (tmp.contains("terminal")) {
+                terminal_cmd = tmp;
+                if (tmp == "mate-terminal") {
+                    break;
+                }
             }
+            l = l->next;
         }
-        l = l->next;
-    }
-    g_list_free_full(infos, g_object_unref);
+        g_list_free_full(infos, g_object_unref);
+    });
 }
 
 void HeaderBar::openDefaultTerminal()
@@ -369,9 +380,9 @@ void HeaderBar::finishEdit()
 
 void HeaderBar::updateIcons()
 {
-    qDebug()<<m_window->getCurrentUri();
-    qDebug()<<m_window->getCurrentSortColumn();
-    qDebug()<<m_window->getCurrentSortOrder();
+    qDebug()<<"updateIcons:" <<m_window->getCurrentUri();
+    qDebug()<<"updateIcons:" <<m_window->getCurrentSortColumn();
+    qDebug()<<"updateIcons:" <<m_window->getCurrentSortOrder();
     m_view_type_menu->setCurrentDirectory(m_window->getCurrentUri());
     m_view_type_menu->setCurrentView(m_window->getCurrentPage()->getView()->viewId(), true);
     m_sort_type_menu->switchSortTypeRequest(m_window->getCurrentSortColumn());
@@ -625,4 +636,11 @@ void HeaderBarContainer::addWindowButtons()
         w->setProperty("useIconHighlightEffect", true);
         w->setProperty("iconHighlightEffectMode", 1);
     }
+
+    if (gPlatform == "wayland") {
+        minimize->setVisible(false);
+        maximizeAndRestore->setVisible(false);
+        close->setVisible(false);
+        m_layout->removeItem(layout);
+    }
 }
