@@ -24,6 +24,7 @@
 #include "side-bar-model.h"
 #include "side-bar-proxy-filter-sort-model.h"
 #include "side-bar-abstract-item.h"
+#include "volume-manager.h"
 
 #include "side-bar-menu.h"
 #include "side-bar-abstract-item.h"
@@ -54,6 +55,8 @@
 
 #include <QDebug>
 
+using namespace Peony;
+
 NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
 {
     setIconSize(QSize(16, 16));
@@ -95,6 +98,17 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
 
     this->setModel(m_proxy_model);
 
+    VolumeManager *volumeManager = VolumeManager::getInstance();
+    connect(volumeManager,&Peony::VolumeManager::volumeAdded,this,[=](const std::shared_ptr<Peony::Volume> &volume){
+        m_proxy_model->invalidate();//display DVD device in real time.
+    });
+    connect(volumeManager,&Peony::VolumeManager::volumeRemoved,this,[=](const std::shared_ptr<Peony::Volume> &volume){
+        m_proxy_model->invalidate();//The drive does not display when the DVD device is removed.
+    });
+    connect(volumeManager,&Peony::VolumeManager::driveDisconnected,this,[=](const std::shared_ptr<Peony::Drive> &drive){
+        m_proxy_model->invalidate();//Multiple udisk eject display problem
+    });
+
     connect(this, &QTreeView::expanded, [=](const QModelIndex &index) {
         auto item = m_proxy_model->itemFromIndex(index);
         qDebug()<<item->uri();
