@@ -29,6 +29,7 @@
 #include <QLabel>
 #include <QToolButton>
 #include <QWidgetAction>
+#include <QStandardPaths>
 #include <KWindowSystem>
 
 #include "global-settings.h"
@@ -155,6 +156,7 @@ OperationMenuEditWidget::OperationMenuEditWidget(MainWindow *window, QWidget *pa
     copy->setIcon(QIcon::fromTheme("edit-copy-symbolic"));
     copy->setIconSize(QSize(16, 16));
     copy->setAutoRaise(false);
+    copy->setToolTip(tr("copy"));
     hbox->addWidget(copy);
 
     auto paste = new QToolButton(this);
@@ -163,6 +165,7 @@ OperationMenuEditWidget::OperationMenuEditWidget(MainWindow *window, QWidget *pa
     paste->setIcon(QIcon::fromTheme("edit-paste-symbolic"));
     paste->setIconSize(QSize(16, 16));
     paste->setAutoRaise(false);
+    paste->setToolTip(tr("paste"));
     hbox->addWidget(paste);
 
     auto cut = new QToolButton(this);
@@ -171,6 +174,7 @@ OperationMenuEditWidget::OperationMenuEditWidget(MainWindow *window, QWidget *pa
     cut->setIcon(QIcon::fromTheme("edit-cut-symbolic"));
     cut->setIconSize(QSize(16, 16));
     cut->setAutoRaise(false);
+    cut->setToolTip(tr("cut"));
     hbox->addWidget(cut);
 
     auto trash = new QToolButton(this);
@@ -179,6 +183,7 @@ OperationMenuEditWidget::OperationMenuEditWidget(MainWindow *window, QWidget *pa
     trash->setIcon(QIcon::fromTheme("ukui-user-trash"));
     trash->setIconSize(QSize(16, 16));
     trash->setAutoRaise(false);
+    trash->setToolTip(tr("trash"));
     hbox->addWidget(trash);
 
     vbox->addLayout(hbox);
@@ -205,7 +210,14 @@ OperationMenuEditWidget::OperationMenuEditWidget(MainWindow *window, QWidget *pa
     });
 
     connect(m_paste, &QToolButton::clicked, this, [=]() {
-        Peony::ClipboardUtils::pasteClipboardFiles(window->getCurrentUri());
+        auto op = Peony::ClipboardUtils::pasteClipboardFiles(window->getCurrentUri());
+        if (op) {
+            connect(op, &Peony::FileOperation::operationFinished, window, [=](){
+                auto opInfo = op->getOperationInfo();
+                auto targetUirs = opInfo->dests();
+                window->setCurrentSelectionUris(targetUirs);
+            }, Qt::BlockingQueuedConnection);
+        }
         Q_EMIT operationAccepted();
     });
 
@@ -236,14 +248,16 @@ void OperationMenuEditWidget::updateActions(const QString &currentDirUri, const
 {
     //FIXME:
     bool isSelectionEmpty = selections.isEmpty();
-    m_copy->setEnabled(!isSelectionEmpty);
-    m_cut->setEnabled(!isSelectionEmpty);
-    m_trash->setEnabled(!isSelectionEmpty);
+    QString desktopPath = "file://" +  QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+    QString desktopUri = Peony::FileUtils::getEncodedUri(desktopPath);
+    QString homeUri = "file://" +  QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+    bool isDesktop = selections.contains(desktopUri);
+    bool isHome = selections.contains(homeUri);
+    bool isSearch = currentDirUri.startsWith("search://");
+    m_copy->setEnabled(!isSelectionEmpty && !isSearch);
+    m_cut->setEnabled(!isSelectionEmpty && !isDesktop && !isHome && !isSearch);
+    m_trash->setEnabled(!isSelectionEmpty && !isDesktop && !isHome && !isSearch);
 
-    if (isSelectionEmpty) {
-        bool isClipboradHasFile = Peony::ClipboardUtils::isClipboardHasFiles();
-        m_paste->setEnabled(isClipboradHasFile);
-    } else {
-        m_paste->setEnabled(false);
-    }
+    bool isClipboradHasFile = Peony::ClipboardUtils::isClipboardHasFiles();
+    m_paste->setEnabled(isClipboradHasFile);
 }
