@@ -104,6 +104,7 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     m_tab_bar_bg = new QWidget(this);
     m_tab_bar_bg->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     QToolBar *previewButtons = new QToolBar(this);
+    m_tool_bar = previewButtons;
     //previewButtons->setFixedHeight(m_tab_bar->height());
     t->setContentsMargins(0, 0, 5, 0);
     t->addWidget(m_tab_bar_bg);
@@ -336,7 +337,7 @@ void TabWidget::searchChildUpdate()
 
 void TabWidget::browsePath()
 {
-    QString target_path = QFileDialog::getExistingDirectory(this, "caption", getCurrentUri(), QFileDialog::ShowDirsOnly);
+    QString target_path = QFileDialog::getExistingDirectory(this, tr("Select path"), getCurrentUri(), QFileDialog::ShowDirsOnly);
     qDebug()<<"browsePath Opened:"<<target_path;
     //add root prefix
     if (! target_path.contains("file://") && target_path != "")
@@ -550,6 +551,11 @@ void TabWidget::updateTrashBarVisible(const QString &uri)
     m_trash_label->setVisible(visible);
     m_clear_button->setVisible(visible);
     m_recover_button->setVisible(visible);
+
+    if (uri.startsWith("trash://") || uri.startsWith("recent://"))
+        m_tool_bar->setVisible(false);
+    else
+        m_tool_bar->setVisible(true);
 }
 
 void TabWidget::handleZoomLevel(int zoomLevel)
@@ -637,10 +643,18 @@ void TabWidget::updateSearchPathButton(const QString &uri)
         if (! getCurrentUri().isNull())
             curUri = getCurrentUri();
     }
+    //FIXME: replace BLOCKING api in ui thread.
     auto iconName = Peony::FileUtils::getFileIconName(curUri);
     auto displayName = Peony::FileUtils::getFileDisplayName(curUri);
     qDebug() << "iconName:" <<iconName <<displayName<<curUri;
     m_search_path->setIcon(QIcon::fromTheme(iconName));
+
+    //elide text if it is too long
+    if (displayName.length() > ELIDE_TEXT_LENGTH)
+    {
+        int  charWidth = fontMetrics().averageCharWidth();
+        displayName = fontMetrics().elidedText(displayName, Qt::ElideRight, ELIDE_TEXT_LENGTH * charWidth);
+    }
     m_search_path->setText(displayName);
 }
 
@@ -790,7 +804,6 @@ void TabWidget::setPreviewPage(Peony::PreviewPageIface *previewPage)
 void TabWidget::addPage(const QString &uri, bool jumpTo)
 {
     auto info = Peony::FileInfo::fromUri(uri, false);
-    qDebug() << "addPage:" <<uri <<info->isDir();
     if (! info->isDir())
         return;
 
@@ -982,6 +995,8 @@ void TabWidget::updateAdvanceConditions()
 void TabWidget::setCurrentSelections(const QStringList &uris)
 {
     currentPage()->getView()->setSelections(uris);
+    if (uris.count() >0)
+        currentPage()->getView()->scrollToSelection(uris.first());
 }
 
 void TabWidget::editUri(const QString &uri)
@@ -1004,7 +1019,12 @@ void TabWidget::onViewDoubleClicked(const QString &uri)
         return;
     }
     if (info->isDir() || info->isVolume() || info->isVirtual()) {
-        Q_EMIT this->updateWindowLocationRequest(uri, true);
+        //process open symbolic link
+        auto info = Peony::FileInfo::fromUri(uri, false);
+        QString targetUri = info.get()->targetUri();
+        if (targetUri.isEmpty())
+            targetUri = uri;
+        Q_EMIT this->updateWindowLocationRequest(targetUri, true);
     } else {
         Peony::FileLaunchManager::openAsync(uri, false, false);
     }
@@ -1063,6 +1083,12 @@ void TabWidget::bindContainerSignal(Peony::DirectoryViewContainer *container)
         m_status_bar->m_slider->setEnabled(enable);
         m_status_bar->m_slider->setVisible(enable);
     });
+
+    connect(container, &Peony::DirectoryViewContainer::updateWindowSelectionRequest, this, [=](const QStringList &uris){
+        if (container == currentPage()) {
+            Q_EMIT this->updateWindowSelectionRequest(uris);
+        }
+    });
 }
 
 void TabWidget::updatePreviewPage()
