@@ -36,10 +36,11 @@ public:
     explicit ViewTypeMenu(QWidget *parent = nullptr);
 
 Q_SIGNALS:
-    void switchViewRequest(const QString &viewId, const QIcon &icon);
+    void switchViewRequest(const QString &viewId, const QIcon &icon, bool resetToZoomLevelHint = false);
+    void updateZoomLevelHintRequest(int zoomLevelHint);
 
 public Q_SLOTS:
-    void setCurrentView(const QString &viewId);
+    void setCurrentView(const QString &viewId, bool blockSignal = false);
     void setCurrentDirectory(const QString &uri);
 
 protected:
