@@ -106,6 +106,9 @@
 #define KYLIN_USER_GUIDE_SERVICE QString("com.kylinUserGuide.hotel_%1").arg(getuid())
 #define KYLIN_USER_GUIDE_INTERFACE "com.guide.hotel"
 
+//record of peony start time
+qint64 PeonyApplication::peony_start_time = 0;
+
 PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicationName) : SingleApplication (argc, argv, applicationName, true)
 {
     setApplicationVersion("v3.0.0");
@@ -494,6 +497,9 @@ void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
             //FIXME: show item parent folder and set selection for item.
             QHash<QString, QStringList> itemHash;
             auto uris = Peony::FileUtils::toDisplayUris(parser.positionalArguments());
+            if (uris.isEmpty()) {
+                return;
+            }
             for (auto uri : uris) {
                 auto parentUri = Peony::FileUtils::getParentUri(uri);
                 if (itemHash.value(parentUri).isEmpty()) {
@@ -525,6 +531,9 @@ void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
 
         if (parser.isSet(showFoldersOption)) {
             QStringList uris = Peony::FileUtils::toDisplayUris(parser.positionalArguments());
+            if (uris.isEmpty()) {
+                return;
+            }
             auto window = new MainWindow(uris.first());
             //Peony::FMWindow *window = new Peony::FMWindow(uris.first());
             uris.removeAt(0);
@@ -536,14 +545,21 @@ void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
         }
         if (parser.isSet(showPropertiesOption)) {
             QStringList uris = Peony::FileUtils::toDisplayUris(parser.positionalArguments());
+            if (uris.isEmpty()) {
+                return;
+            }
 
             Peony::PropertiesWindow *window = new Peony::PropertiesWindow(uris);
+            window->setAttribute(Qt::WA_DeleteOnClose);
             window->show();
             KWindowSystem::raiseWindow(window->winId());
         }
     } else {
         if (!parser.positionalArguments().isEmpty()) {
             QStringList uris = Peony::FileUtils::toDisplayUris(parser.positionalArguments());
+            if (uris.isEmpty()) {
+                return;
+            }
             //auto window = new Peony::FMWindow(uris.first());
             auto window = new MainWindow(uris.first());
             uris.removeAt(0);
@@ -572,13 +588,16 @@ void PeonyApplication::parseCmd(quint32 id, QByteArray msg)
 
 void PeonyApplication::about()
 {
-    QMessageBox::about(nullptr,
-                       tr("Peony Qt"),
-                       tr("Author:\n"
-                          "\tYue Lan <lanyue@kylinos.cn>\n"
-                          "\tMeihong He <hemeihong@kylinos.cn>\n"
-                          "\n"
-                          "Copyright (C): 2020, KylinSoft Co., Ltd."));
+    QMessageBox *msgBox = new QMessageBox();
+    msgBox->setWindowTitle(tr("Peony Qt"));
+    msgBox->setText(tr("Author:\n"
+                       "\tYue Lan <lanyue@kylinos.cn>\n"
+                       "\tMeihong He <hemeihong@kylinos.cn>\n"
+                       "\n"
+                       "Copyright (C): 2020, KylinSoft Co., Ltd."));
+    msgBox->setModal(false);
+    msgBox->setAttribute(Qt::WA_DeleteOnClose);
+    msgBox->show();
 }
 
 void PeonyApplication::help()
