@@ -35,7 +35,6 @@
 #include "tab-widget.h"
 #include "peony-screen.h"
 
-
 void messageOutput(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
     QByteArray localMsg = msg.toLocal8Bit();
@@ -80,12 +79,14 @@ void messageOutput(QtMsgType type, const QMessageLogContext &context, const QStr
 }
 
 int main(int argc, char *argv[]) {
+    PeonyApplication::peony_start_time = QDateTime::currentMSecsSinceEpoch();
     qInstallMessageHandler(messageOutput);
+    qDebug() << "peony start in main time:" <<PeonyApplication::peony_start_time ;
     PeonyScreen *screen = new PeonyScreen();
-    if (screen->getScreenWidth() >2560) {
-        QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-        QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    }
+
+    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+
     delete screen;
 
     PeonyApplication app(argc, argv, "peony-qt");
