@@ -67,6 +67,7 @@
 #include "peony-application.h"
 
 #include "global-settings.h"
+#include "audio-play-manager.h"
 
 #include <QSplitter>
 
@@ -79,6 +80,7 @@
 #include <QDesktopServices>
 
 #include <QProcess>
+#include <QDateTime>
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
 #include <QPainterPath>
@@ -96,9 +98,14 @@
 #define FONT_SETTINGS "org.ukui.style"
 
 static MainWindow *last_resize_window = nullptr;
+static QString gPlatform = nullptr;
 
 MainWindow::MainWindow(const QString &uri, QWidget *parent) : QMainWindow(parent)
 {
+    if (gPlatform.isNull()) {
+        gPlatform = qgetenv("XDG_SESSION_TYPE");
+    }
+
     setContextMenuPolicy(Qt::CustomContextMenu);
     installEventFilter(this);
 
@@ -111,9 +118,9 @@ MainWindow::MainWindow(const QString &uri, QWidget *parent) : QMainWindow(parent
     setStyle(PeonyMainWindowStyle::getStyle());
 
     m_effect = new BorderShadowEffect(this);
-    m_effect->setPadding(4);
-    m_effect->setBorderRadius(6);
-    m_effect->setBlurRadius(4);
+    m_effect->setPadding(0);
+    m_effect->setBorderRadius(0);
+    m_effect->setBlurRadius(0);
     //setGraphicsEffect(m_effect);
 
     setAnimated(false);
@@ -121,10 +128,10 @@ MainWindow::MainWindow(const QString &uri, QWidget *parent) : QMainWindow(parent
     setAttribute(Qt::WA_TranslucentBackground);
     //setAttribute(Qt::WA_OpaquePaintEvent);
     //fix double window base buttons issue, not effect MinMax button hints
-    auto flags = windowFlags() &~Qt::WindowMinMaxButtonsHint;
-    setWindowFlags(flags |Qt::FramelessWindowHint);
+    //auto flags = windowFlags() &~Qt::WindowMinMaxButtonsHint;
+    //setWindowFlags(flags |Qt::FramelessWindowHint);
     //setWindowFlags(windowFlags()|Qt::FramelessWindowHint);
-    setContentsMargins(4, 4, 4, 4);
+    //setContentsMargins(4, 4, 4, 4);
 
     //bind resize handler
     auto handler = new QWidgetResizeHandler(this);
@@ -139,6 +146,19 @@ MainWindow::MainWindow(const QString &uri, QWidget *parent) : QMainWindow(parent
 
     //init UI
     initUI(uri);
+
+    if (gPlatform == "x11") {
+        XAtomHelper::getInstance()->setUKUIDecoraiontHint(this->winId(), true);
+        MotifWmHints hints;
+        hints.flags = MWM_HINTS_FUNCTIONS|MWM_HINTS_DECORATIONS;
+        hints.functions = MWM_FUNC_ALL;
+        hints.decorations = MWM_DECOR_BORDER;
+        XAtomHelper::getInstance()->setWindowMotifHint(this->winId(), hints);
+    }
+
+    auto start_cost_time = QDateTime::currentMSecsSinceEpoch()- PeonyApplication::peony_start_time;
+    qDebug() << "peony start end in main-window time:" <<start_cost_time
+             <<"ms"<<QDateTime::currentMSecsSinceEpoch();
 }
 
 MainWindow::~MainWindow()
@@ -253,17 +273,20 @@ void MainWindow::checkSettings()
     m_use_default_name_sort_order = settings->isExist("chinese-first")? settings->getValue("chinese-first").toBool(): false;
     m_folder_first = settings->isExist("folder-first")? settings->getValue("folder-first").toBool(): true;
 
-    //font monitor
-    QGSettings *fontSetting = new QGSettings(FONT_SETTINGS, QByteArray(), this);
-    connect(fontSetting, &QGSettings::changed, this, [=](const QString &key){
-        qDebug() << "fontSetting changed:" << key;
-        if (key == "systemFont" || key == "systemFontSize")
-        {
-            QFont font = this->font();
-            for(auto widget : qApp->allWidgets())
-                widget->setFont(font);
-        }
-    });
+    if (QGSettings::isSchemaInstalled("org.ukui.style"))
+    {
+        //font monitor
+        QGSettings *fontSetting = new QGSettings(FONT_SETTINGS, QByteArray(), this);
+        connect(fontSetting, &QGSettings::changed, this, [=](const QString &key){
+            qDebug() << "fontSetting changed:" << key;
+            if (key == "systemFont" || key == "systemFontSize")
+            {
+                QFont font = this->font();
+                for(auto widget : qApp->allWidgets())
+                    widget->setFont(font);
+            }
+        });
+    }
 }
 
 void MainWindow::setShortCuts()
@@ -301,8 +324,15 @@ void MainWindow::setShortCuts()
     auto trashAction = new QAction(this);
     trashAction->setShortcuts(QList<QKeySequence>()<<Qt::Key_Delete<<QKeySequence(Qt::CTRL + Qt::Key_D));
     connect(trashAction, &QAction::triggered, [=]() {
+        auto currentUri = getCurrentUri();
+        if (currentUri.startsWith("search://"))
+            return;
+
         auto uris = this->getCurrentSelections();
-        if (!uris.isEmpty()) {
+        QString desktopPath = "file://" +  QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+        QString desktopUri = Peony::FileUtils::getEncodedUri(desktopPath);
+        QString homeUri = "file://" +  QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+        if (!uris.isEmpty() && !uris.contains(desktopUri) && !uris.contains(homeUri)) {
             bool isTrash = this->getCurrentUri() == "trash:///";
             if (!isTrash) {
                 Peony::FileOperationUtils::trash(uris, true);
@@ -317,8 +347,16 @@ void MainWindow::setShortCuts()
     deleteAction->setShortcuts(QList<QKeySequence>()<<QKeySequence(Qt::SHIFT + Qt::Key_Delete));
     addAction(deleteAction);
     connect(deleteAction, &QAction::triggered, [=]() {
+        auto currentUri = getCurrentUri();
+        if (currentUri.startsWith("search://"))
+            return;
+
         auto uris = this->getCurrentSelections();
-        Peony::FileOperationUtils::executeRemoveActionWithDialog(uris);
+        QString desktopPath = "file://" +  QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+        QString desktopUri = Peony::FileUtils::getEncodedUri(desktopPath);
+        QString homeUri = "file://" +  QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+        if (! uris.contains(desktopUri) && !uris.contains(homeUri))
+           Peony::FileOperationUtils::executeRemoveActionWithDialog(uris);
     });
 
     auto searchAction = new QAction(this);
@@ -412,11 +450,19 @@ void MainWindow::setShortCuts()
                                          <<QKeySequence(Qt::ALT + Qt::Key_Enter));
     connect(propertiesWindowAction, &QAction::triggered, this, [=]() {
         //Fixed issue:when use this shortcut without any selections, this will crash
+        QStringList uris;
         if (getCurrentSelections().count() > 0)
         {
-            Peony::PropertiesWindow *w = new Peony::PropertiesWindow(getCurrentSelections());
-            w->show();
+            uris<<getCurrentSelections();
         }
+        else
+        {
+            uris<<getCurrentUri();
+        }
+
+        Peony::PropertiesWindow *w = new Peony::PropertiesWindow(uris);
+        w->setAttribute(Qt::WA_DeleteOnClose);
+        w->show();
     });
     addAction(propertiesWindowAction);
 
@@ -430,10 +476,11 @@ void MainWindow::setShortCuts()
     auto maxAction = new QAction(this);
     maxAction->setShortcut(QKeySequence(Qt::Key_F11));
     connect(maxAction, &QAction::triggered, this, [=]() {
-        if (!this->isFullScreen()) {
-            this->showFullScreen();
-        } else {
+        //showFullScreen has some issue, change to showMaximized, fix #20043
+        if (!this->isMaximized()) {
             this->showMaximized();
+        } else {
+            this->showNormal();
         }
     });
     addAction(maxAction);
@@ -535,20 +582,38 @@ void MainWindow::setShortCuts()
     copyAction->setShortcut(QKeySequence::Copy);
     connect(copyAction, &QAction::triggered, [=]() {
         if (!this->getCurrentSelections().isEmpty())
+        {
             if (this->getCurrentSelections().first().startsWith("trash://", Qt::CaseInsensitive)) {
                 return ;
             }
-            Peony::ClipboardUtils::setClipboardFiles(this->getCurrentSelections(), false);
+            if (this->getCurrentSelections().first().startsWith("recent://", Qt::CaseInsensitive)) {
+                return ;
+            }
+        }
+        Peony::ClipboardUtils::setClipboardFiles(this->getCurrentSelections(), false);
     });
     addAction(copyAction);
 
     auto *pasteAction = new QAction(this);
     pasteAction->setShortcut(QKeySequence::Paste);
     connect(pasteAction, &QAction::triggered, [=]() {
+        auto currentUri = getCurrentUri();
+        if (currentUri.startsWith("trash://") || currentUri.startsWith("recent://")
+            || currentUri.startsWith("computer://") || currentUri.startsWith("favorite://"))
+        {
+            return;
+        }
         if (Peony::ClipboardUtils::isClipboardHasFiles()) {
             //FIXME: how about duplicated copy?
             //FIXME: how to deal with a failed move?
-            Peony::ClipboardUtils::pasteClipboardFiles(this->getCurrentUri());
+            auto op = Peony::ClipboardUtils::pasteClipboardFiles(this->getCurrentUri());
+            if (op) {
+                connect(op, &Peony::FileOperation::operationFinished, this, [=](){
+                    auto opInfo = op->getOperationInfo();
+                    auto targetUirs = opInfo->dests();
+                    setCurrentSelectionUris(targetUirs);
+                }, Qt::BlockingQueuedConnection);
+            }
         }
     });
     addAction(pasteAction);
@@ -560,7 +625,15 @@ void MainWindow::setShortCuts()
             if (this->getCurrentSelections().first().startsWith("trash://", Qt::CaseInsensitive)) {
                 return ;
             }
-            Peony::ClipboardUtils::setClipboardFiles(this->getCurrentSelections(), true);
+            if (this->getCurrentSelections().first().startsWith("recent://", Qt::CaseInsensitive)) {
+                return ;
+            }
+
+            QString desktopPath = "file://" +  QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+            QString desktopUri = Peony::FileUtils::getEncodedUri(desktopPath);
+            QString homeUri = "file://" +  QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+            if (! this->getCurrentSelections().contains(desktopUri) && ! this->getCurrentSelections().contains(homeUri))
+                Peony::ClipboardUtils::setClipboardFiles(this->getCurrentSelections(), true);
         }
     });
     addAction(cutAction);
@@ -569,6 +642,7 @@ void MainWindow::setShortCuts()
 void MainWindow::updateTabPageTitle()
 {
     m_tab->updateTabPageTitle();
+    //FIXME: replace BLOCKING api in ui thread.
     auto show = Peony::FileUtils::getFileDisplayName(getCurrentUri());
     QString title = show + "-" + tr("File Manager");
     //qDebug() << "updateTabPageTitle:" <<title;
@@ -577,16 +651,28 @@ void MainWindow::updateTabPageTitle()
 
 void MainWindow::createFolderOperation()
 {
-    Peony::CreateTemplateOperation op(getCurrentUri(), Peony::CreateTemplateOperation::EmptyFolder, tr("New Folder"));
-    Peony::FileOperationErrorDialogConflict dlg;
-    connect(&op, &Peony::FileOperation::errored, &dlg, &Peony::FileOperationErrorDialogConflict::handle);
-    op.run();
-    auto targetUri = op.target();
+//    Peony::CreateTemplateOperation op(getCurrentUri(), Peony::CreateTemplateOperation::EmptyFolder, tr("New Folder"));
+//    Peony::FileOperationErrorDialogConflict dlg;
+//    connect(&op, &Peony::FileOperation::errored, &dlg, &Peony::FileOperationErrorDialogConflict::handle);
+//    op.run();
+//    auto targetUri = op.target();
 
-    QTimer::singleShot(500, this, [=]() {
-        this->getCurrentPage()->getView()->scrollToSelection(targetUri);
-        this->editUri(targetUri);
-    });
+    auto op = Peony::FileOperationUtils::create(getCurrentUri(), tr("New Folder"), Peony::CreateTemplateOperation::EmptyFolder);
+    connect(op, &Peony::FileOperation::operationFinished, this, [=](){
+        if (op->hasError())
+            return;
+        auto opInfo = op->getOperationInfo();
+        auto targetUri = opInfo->target();
+        this->getCurrentPage()->getView()->clearIndexWidget();
+        QTimer::singleShot(500, this, [=](){
+            this->editUri(opInfo->target());
+        });
+    }, Qt::BlockingQueuedConnection);
+
+//    QTimer::singleShot(500, this, [=]() {
+//        this->getCurrentPage()->getView()->scrollToSelection(targetUri);
+//        this->editUri(targetUri);
+//    });
 }
 
 void MainWindow::keyPressEvent(QKeyEvent *e)
@@ -732,6 +818,13 @@ void MainWindow::goToUri(const QString &uri, bool addHistory, bool force)
 
 void MainWindow::addNewTabs(const QStringList &uris)
 {
+    //fix search path add new tab,page title show abnormal issue
+    if (uris.count() == 1)
+    {
+        m_tab->addPage(uris.first(), true);
+        return;
+    }
+
     for (auto uri : uris) {
         m_tab->addPage(uri, false);
     }
@@ -746,7 +839,11 @@ void MainWindow::beginSwitchView(const QString &viewId)
     // save zoom level
     Peony::GlobalSettings::getInstance()->setValue(DEFAULT_VIEW_ZOOM_LEVEL, currentViewZoomLevel());
     m_tab->setCurrentSelections(selection);
-    m_tab->m_status_bar->m_slider->setEnabled(m_tab->currentPage()->getView()->supportZoom());
+    bool supportZoom = m_tab->currentPage()->getView()->supportZoom();
+    m_tab->m_status_bar->m_slider->setEnabled(supportZoom);
+    m_tab->m_status_bar->m_slider->setVisible(supportZoom);
+    //fix slider value not update issue
+    m_tab->m_status_bar->m_slider->setValue(currentViewZoomLevel());
 }
 
 void MainWindow::refresh()
@@ -814,9 +911,11 @@ void MainWindow::forceStopLoading()
 void MainWindow::setCurrentSelectionUris(const QStringList &uris)
 {
     m_tab->setCurrentSelections(uris);
-    if (uris.isEmpty())
-        return;
-    getCurrentPage()->getView()->scrollToSelection(uris.first());
+    //move scrollToSelection to m_tab to try fix new unzip file show two same icon issue
+    //Fix me, unknow caused reason
+//    if (uris.isEmpty())
+//        return;
+//    getCurrentPage()->getView()->scrollToSelection(uris.first());
 }
 
 void MainWindow::setCurrentSortOrder(Qt::SortOrder order)
@@ -896,10 +995,10 @@ void MainWindow::paintEvent(QPaintEvent *e)
     if (qApp->property("blurEnable").isValid()) {
         bool blurEnable = qApp->property("blurEnable").toBool();
         if (!blurEnable) {
-            colorBase.setAlphaF(1);
+            colorBase.setAlphaF(0.9);
         }
     } else {
-        colorBase.setAlphaF(1);
+        colorBase.setAlphaF(0.9);
     }
 
     QPainterPath sidebarPath;
@@ -939,6 +1038,7 @@ void MainWindow::mouseMoveEvent(QMouseEvent *e)
     if (!m_is_draging)
         return;
 
+    qreal  dpiRatio = qApp->devicePixelRatio();
     if (QX11Info::isPlatformX11()) {
         Display *display = QX11Info::display();
         Atom netMoveResize = XInternAtom(display, "_NET_WM_MOVERESIZE", False);
@@ -951,8 +1051,8 @@ void MainWindow::mouseMoveEvent(QMouseEvent *e)
         xEvent.xclient.display = display;
         xEvent.xclient.window = this->winId();
         xEvent.xclient.format = 32;
-        xEvent.xclient.data.l[0] = pos.x();
-        xEvent.xclient.data.l[1] = pos.y();
+        xEvent.xclient.data.l[0] = pos.x() * dpiRatio;
+        xEvent.xclient.data.l[1] = pos.y() * dpiRatio;
         xEvent.xclient.data.l[2] = 8;
         xEvent.xclient.data.l[3] = Button1;
         xEvent.xclient.data.l[4] = 0;
@@ -969,10 +1069,10 @@ void MainWindow::mouseMoveEvent(QMouseEvent *e)
         xevent.type = ButtonRelease;
         xevent.xbutton.button = Button1;
         xevent.xbutton.window = this->winId();
-        xevent.xbutton.x = e->pos().x();
-        xevent.xbutton.y = e->pos().y();
-        xevent.xbutton.x_root = pos.x();
-        xevent.xbutton.y_root = pos.y();
+        xevent.xbutton.x = e->pos().x() * dpiRatio;
+        xevent.xbutton.y = e->pos().y() * dpiRatio;
+        xevent.xbutton.x_root = pos.x() * dpiRatio;
+        xevent.xbutton.y_root = pos.y() * dpiRatio;
         xevent.xbutton.display = display;
 
         XSendEvent(display, this->effectiveWinId(), False, ButtonReleaseMask, &xevent);
@@ -987,7 +1087,7 @@ void MainWindow::mouseMoveEvent(QMouseEvent *e)
 
         m_is_draging = false;
     } else {
-        this->move(QCursor::pos() - m_offset);
+        this->move((QCursor::pos() - m_offset) * dpiRatio);
     }
 }
 
@@ -1011,15 +1111,16 @@ void MainWindow::validBorder()
         setProperty("blurRegion", QVariant());
         KWindowEffects::enableBlurBehind(this->winId(), true);
     } else {
-        setContentsMargins(4, 4, 4, 4);
+        //setContentsMargins(4, 4, 4, 4);
         m_effect->setPadding(4);
         QPainterPath path;
         auto rect = this->rect();
         rect.adjust(4, 4, -4, -4);
         path.addRoundedRect(rect, 6, 6);
-        setProperty("blurRegion", QRegion(path.toFillPolygon().toPolygon()));
+        //setProperty("blurRegion", QRegion(path.toFillPolygon().toPolygon()));
         //use KWindowEffects
-        KWindowEffects::enableBlurBehind(this->winId(), true, QRegion(path.toFillPolygon().toPolygon()));
+        //KWindowEffects::enableBlurBehind(this->winId(), true, QRegion(path.toFillPolygon().toPolygon()));
+        KWindowEffects::enableBlurBehind(this->winId(), true);
     }
 }
 
@@ -1187,6 +1288,9 @@ void MainWindow::initUI(const QString &uri)
             });
         }
     });
+    connect(m_tab, &TabWidget::updateWindowSelectionRequest, this, [=](const QStringList &uris){
+        setCurrentSelectionUris(uris);
+    });
 //    connect(m_tab, &TabWidget::currentSelectionChanged, this, [=](){
 //        m_status_bar->update();
 //    });
@@ -1194,6 +1298,7 @@ void MainWindow::initUI(const QString &uri)
 
 void MainWindow::cleanTrash()
 {
+    Peony::AudioPlayManager::getInstance()->playWarningAudio();
     auto result = QMessageBox::question(nullptr, tr("Delete Permanently"),
                                         tr("Are you sure that you want to delete these files? "
                                            "Once you start a deletion, the files deleting will never be "
